@@ -53,7 +53,6 @@ IncludeLanguageFile( $gl_root_path . '/lang/' . $LANG . '/admin.php' );
 // --- 
 
 // --- BEGIN Custom Code
-
 // Only if the user is an admin!
 if ( !isset($_SESSION['SESSION_ISADMIN']) || $_SESSION['SESSION_ISADMIN'] == 0 ) 
 	DieWithFriendlyErrorMsg( $content['LN_ADMIN_ERROR_NOTALLOWED'] );
@@ -93,7 +92,7 @@ if ( isset($_GET['op']) )
 			if ( isset($content['DBMP'][ $content['DBMPID'] ]) )
 			{
 				//Set the FormAdd URL
-				$content['FormUrlAddOP'] = "?op=edit&id=" . $content['DBMPID'];
+				$content['FormUrlAddOP'] = "?op=edit&dbmpid=" . $content['DBMPID'];
 
 				$mymapping = $content['DBMP'][ $content['DBMPID'] ];
 				$content['DisplayName'] = $mymapping['DisplayName'] ;
@@ -351,6 +350,9 @@ if ( isset($_POST['op']) )
 				array_splice($content['SUBMAPPINGS'], $iArrayNum-1, 0, $EntryTwoMove);
 			}
 			// --- 
+
+			// Add Focus to MoveUp Button again
+			AddWindowLoadFocus("subop_moveup_" . $szColId); 
 		}
 		else if ( isset($_POST['subop_movedown']) )
 		{
@@ -381,6 +383,9 @@ if ( isset($_POST['op']) )
 				array_splice($content['SUBMAPPINGS'], $iArrayNum+1, 0, $EntryTwoMove);
 			}
 			// --- 
+
+			// Add Focus to MoveDown Button again
+			AddWindowLoadFocus("subop_movedown_" . $szColId); 
 		}
 		else // Now SUBOP means normal processing!
 		{
