@@ -55,6 +55,14 @@ InitFilterHelpers();	// Helpers for frontend filtering!
 // Init admin langauge file now!
 IncludeLanguageFile( $gl_root_path . '/lang/' . $LANG . '/admin.php' );
 
+// --- Deny if DisableAdminUsers is enabled and User is not ADMIN 
+if ( !isset($_SESSION['SESSION_ISADMIN']) || $_SESSION['SESSION_ISADMIN'] == 0 ) 
+{
+	if ( GetConfigSetting("DisableAdminUsers", 0, CFGLEVEL_GLOBAL) == 1 )
+		DieWithFriendlyErrorMsg( $content['LN_ADMIN_ERROR_NOTALLOWED'] );
+}
+// --- 
+
 // --- Deny if User is READONLY!
 if ( !isset($_SESSION['SESSION_ISREADONLY']) || $_SESSION['SESSION_ISREADONLY'] == 1 )
 {
@@ -82,6 +90,10 @@ else
 	$content['DISABLE_GLOBALEDIT_FORMCONTROL'] = "disabled";
 }
 
+// Init Fonts and sizes
+InitFontList(); 
+InitFontSizeList(); 
+
 // --- First thing to do is to check the op get parameter!
 // Check for changes first | Abort if Edit is not allowed
 if ( isset($_GET['op']) && isset($_GET['value']) )
@@ -90,10 +102,23 @@ if ( isset($_GET['op']) && isset($_GET['value']) )
 	{
 		$iNewVal = intval($_GET['value']);
 		if ( $iNewVal == 1 )
+		{
+			// Set UserOption 
 			$USERCFG['UserOverwriteOptions'] = 1;
+
+			// Focus the enable user button
+			AddWindowLoadFocus("buttonenableuseropt"); 
+		}
 		else
+		{
+			// Set UserOption 
 			$USERCFG['UserOverwriteOptions'] = 0;
 
+			// Focus the disable user button
+			AddWindowLoadFocus("buttondisableuseropt"); 
+		}
+
+
 		// Enable User Options!
 		WriteConfigValue( "UserOverwriteOptions", false, $content['SESSION_USERID'] );
 	}
@@ -109,8 +134,6 @@ if ( $UserOverwriteOptions == 1 )
 else
 {
 	$content['ENABLEUSEROPTIONS'] = false;
-
-
 }
 // ---
 
@@ -139,6 +162,10 @@ if ( isset($_POST['op']) )
 			// Read default SOURCES | Check if Source exists as well!
 			if ( isset ($_POST['DefaultSourceID']) && isset($content['Sources'][$_POST['DefaultSourceID']] )) { $content['DefaultSourceID'] = $_POST['DefaultSourceID']; }
 
+			// Read default FONT  Settings
+			if ( isset ($_POST['DefaultFont']) ) { $content['DefaultFont'] = $_POST['DefaultFont']; }
+			if ( isset ($_POST['DefaultFontSize']) ) { $content['DefaultFontSize'] = $_POST['DefaultFontSize']; }
+
 			// Read checkboxes
 			if ( isset ($_POST['ViewUseTodayYesterday']) ) { $content['ViewUseTodayYesterday'] = 1; } else { $content['ViewUseTodayYesterday'] = 0; } 
 			if ( isset ($_POST['ViewEnableDetailPopups']) ) { $content['ViewEnableDetailPopups'] = 1; } else { $content['ViewEnableDetailPopups'] = 0; } 
@@ -153,6 +180,7 @@ if ( isset($_POST['op']) )
 			if ( isset ($_POST['InlineOnlineSearchIcons']) ) { $content['InlineOnlineSearchIcons'] = 1; } else { $content['InlineOnlineSearchIcons'] = 0; } 
 			if ( isset ($_POST['DebugUserLogin']) ) { $content['DebugUserLogin'] = 1; } else { $content['DebugUserLogin'] = 0; } 
 			if ( isset ($_POST['MiscDebugToSyslog']) ) { $content['MiscDebugToSyslog'] = 1; } else { $content['MiscDebugToSyslog'] = 0; } 
+			if ( isset ($_POST['DisableAdminUsers']) ) { $content['DisableAdminUsers'] = 1; } else { $content['DisableAdminUsers'] = 0; } 
 
 			// Read Text number fields
 			if ( isset ($_POST['ViewMessageCharacterLimit']) && is_numeric($_POST['ViewMessageCharacterLimit']) ) { $content['ViewMessageCharacterLimit'] = $_POST['ViewMessageCharacterLimit']; }
@@ -199,6 +227,10 @@ if ( isset($_POST['op']) )
 			// Read default SOURCES | Check if Source exists as well!
 			if ( isset ($_POST['User_DefaultSourceID']) && isset($content['Sources'][$_POST['User_DefaultSourceID']] )) { $USERCFG['DefaultSourceID'] = $_POST['User_DefaultSourceID']; }
 
+			// Read default FONT
+			if ( isset ($_POST['User_DefaultFont']) ) { $USERCFG['DefaultFont'] = $_POST['User_DefaultFont']; }
+			if ( isset ($_POST['User_DefaultFontSize']) ) { $USERCFG['DefaultFontSize'] = $_POST['User_DefaultFontSize']; }
+
 			// Read checkboxes
 			if ( isset ($_POST['User_ViewUseTodayYesterday']) ) { $USERCFG['ViewUseTodayYesterday'] = 1; } else { $USERCFG['ViewUseTodayYesterday'] = 0; } 
 			if ( isset ($_POST['User_ViewEnableDetailPopups']) ) { $USERCFG['ViewEnableDetailPopups'] = 1; } else { $USERCFG['ViewEnableDetailPopups'] = 0; } 
@@ -219,7 +251,6 @@ if ( isset($_POST['op']) )
 			if ( isset ($_POST['User_ViewEntriesPerPage']) && is_numeric($_POST['User_ViewEntriesPerPage']) ) { $USERCFG['ViewEntriesPerPage'] = $_POST['User_ViewEntriesPerPage']; }
 			if ( isset ($_POST['User_ViewEnableAutoReloadSeconds']) && is_numeric($_POST['User_ViewEnableAutoReloadSeconds']) ) { $USERCFG['ViewEnableAutoReloadSeconds'] = $_POST['User_ViewEnableAutoReloadSeconds']; }
 			if ( isset ($_POST['User_AdminChangeWaitTime']) && is_numeric($_POST['User_AdminChangeWaitTime']) ) { $USERCFG['AdminChangeWaitTime'] = $_POST['User_AdminChangeWaitTime']; }
-// TODO!!!!!!!!!!!111111111			
 
 			// Read Text fields
 			if ( isset ($_POST['User_PrependTitle']) ) { $USERCFG['PrependTitle'] = $_POST['User_PrependTitle']; }
@@ -257,10 +288,10 @@ if (isset($content['InlineOnlineSearchIcons']) && $content['InlineOnlineSearchIc
 
 if (isset($content['DebugUserLogin']) && $content['DebugUserLogin'] == 1) { $content['DebugUserLogin_checked'] = "checked"; } else { $content['DebugUserLogin_checked'] = ""; }
 if (isset($content['MiscDebugToSyslog']) && $content['MiscDebugToSyslog'] == 1) { $content['MiscDebugToSyslog_checked'] = "checked"; } else { $content['MiscDebugToSyslog_checked'] = ""; }
+if (isset($content['DisableAdminUsers']) && $content['DisableAdminUsers'] == 1) { $content['DisableAdminUsers_checked'] = "checked"; } else { $content['DisableAdminUsers_checked'] = ""; }
 // --- 
 
 // --- Init for Style field!
-
 // copy STYLES Array
 $content['GLOBAL_STYLES'] = $content['STYLES'];
 $defaultStyleID = GetConfigSetting('ViewDefaultTheme', "default", CFGLEVEL_GLOBAL);
@@ -300,7 +331,7 @@ foreach ( $content['VIEWS'] as &$myView )
 }
 // --- 
 
-// --- Init for DefaultSource  field!
+// --- Init for DefaultSource field!
 // copy Sources Array
 $content['SOURCES'] = $content['Sources'];
 if ( !isset($content['DefaultSourceID']) ) { $content['DefaultSourceID'] = ''; }
@@ -313,6 +344,32 @@ foreach ( $content['SOURCES'] as &$mySource )
 }
 // --- 
 
+// --- Init for DefaultFont field!
+// copy Fonts Array
+$content['FONTS'] = $content['fonts'];
+if ( !isset($content['DefaultFont']) ) { $content['DefaultFont'] = 'Tahoma'; }
+foreach ( $content['FONTS'] as &$myFont )
+{
+	if ( $myFont['Name'] == $content['DefaultFont'] )
+		$myFont['selected'] = "selected";
+	else
+		$myFont['selected'] = "";
+}
+// --- 
+
+// --- Init for DefaultFontSize field!
+// copy Fontsizes Array
+$content['FONTSIZES'] = $content['fontsizes'];
+if ( !isset($content['DefaultFontSize']) ) { $content['DefaultFontSize'] = 100; }
+foreach ( $content['FONTSIZES'] as $myFontKey => &$myFontSize )
+{
+	if ( $myFontKey == $content['DefaultFontSize'] )
+		$myFontSize['selected'] = "selected";
+	else
+		$myFontSize['selected'] = "";
+}
+// --- 
+
 // --- Init for DefaultEncoding field!
 // copy Sources Array
 $content['ENCODINGS'] = $encodings;
@@ -327,8 +384,6 @@ foreach ( $content['ENCODINGS'] as &$myEncoding)
 }
 // --- 
 
-
-
 // Do if User wants extra options
 if ( $content['ENABLEUSEROPTIONS'] )
 {
@@ -410,6 +465,33 @@ if ( $content['ENABLEUSEROPTIONS'] )
 			$mySource['selected'] = "";
 	}
 	// --- 
+
+	// --- Init for DefaultFont field!
+	// copy Fonts Array
+	$content['USER_FONTS'] = $content['fonts'];
+	$DefaultFont = GetConfigSetting('DefaultFont', $content['DefaultFont'], CFGLEVEL_USER);
+	foreach ( $content['USER_FONTS'] as &$myFont )
+	{
+		if ( $myFont['Name'] == $DefaultFont )
+			$myFont['selected'] = "selected";
+		else
+			$myFont['selected'] = "";
+	}
+	// --- 
+
+	// --- Init for DefaultFontSize field!
+	// copy Fontsizes Array
+	$content['USER_FONTSIZES'] = $content['fontsizes'];
+	$DefaultFontSize = GetConfigSetting('DefaultFontSize', $content['DefaultFontSize'], CFGLEVEL_USER);
+	foreach ( $content['USER_FONTSIZES'] as $myFontKey => &$myFontSize )
+	{
+		if ( $myFontKey == $DefaultFontSize )
+			$myFontSize['selected'] = "selected";
+		else
+			$myFontSize['selected'] = "";
+	}
+	// --- 
+
 }
 
 // --- BEGIN CREATE TITLE
@@ -423,5 +505,4 @@ $page -> parser($content, "admin/admin_index.html");
 $page -> output(); 
 // --- 
 
-
 ?>
\ No newline at end of file
