@@ -53,6 +53,14 @@ InitFilterHelpers();	// Helpers for frontend filtering!
 IncludeLanguageFile( $gl_root_path . '/lang/' . $LANG . '/admin.php' );
 // --- 
 
+// --- Deny if DisableAdminUsers is enabled and User is not ADMIN 
+if ( !isset($_SESSION['SESSION_ISADMIN']) || $_SESSION['SESSION_ISADMIN'] == 0 ) 
+{
+	if ( GetConfigSetting("DisableAdminUsers", 0, CFGLEVEL_GLOBAL) == 1 )
+		DieWithFriendlyErrorMsg( $content['LN_ADMIN_ERROR_NOTALLOWED'] );
+}
+// --- 
+
 // --- Deny if User is READONLY!
 if ( !isset($_SESSION['SESSION_ISREADONLY']) || $_SESSION['SESSION_ISREADONLY'] == 1 )
 {
@@ -72,6 +80,20 @@ if ( !isset($_SESSION['SESSION_ISREADONLY']) || $_SESSION['SESSION_ISREADONLY']
 }
 // --- 
 
+// --- FIX MSIE8 Button Values
+if (isset($_POST['op']))
+{
+	if (strpos($_POST['op'], $content['LN_REPORTS_ADDSAVEDREPORTANDRETURN']) !== false )
+		$_POST['op'] = "addsavedreport_return"; 
+	else if (strpos($_POST['op'], $content['LN_REPORTS_EDITSAVEDREPORTANDRETURN']) !== false )
+		$_POST['op'] = "editsavedreport_return"; 
+	else if (strpos($_POST['op'], $content['LN_REPORTS_ADDSAVEDREPORT']) !== false )
+		$_POST['op'] = "addsavedreport"; 
+	else if (strpos($_POST['op'], $content['LN_REPORTS_EDITSAVEDREPORT']) !== false )
+		$_POST['op'] = "editsavedreport"; 
+}
+// ---
+
 // --- BEGIN Custom Code
 $content['OPTIONAL_TITLE'] = "";
 
@@ -456,8 +478,15 @@ if ( isset($_GET['op']) )
 							$mySource['sourceselected'] = "";
 					}
 					
-					// Check if logstream is optimized!
-					CheckConfiguredLogStreamSource($myReport, $content['SourceID']); 
+					// Check if sourceid is valid 
+					if ( !isset($content['SourceID']) ) {
+						$content['ISERROR'] = true;
+						$content['ERROR_CODE'] = ERROR_SOURCENOTFOUND; 
+						$content['ERROR_MSG'] = GetAndReplaceLangStr( $content['LN_GEN_ERROR_SOURCENOTFOUND'], $mySource['ID']);
+					} else {
+						// Check if logstream is optimized!
+						CheckConfiguredLogStreamSource($myReport, $content['SourceID']); 
+					}
 
 					// Create Outputlist
 					$content['outputFormat'] = $mySavedReport['outputFormat']; 
@@ -824,7 +853,7 @@ if ( isset($content['ISADDSAVEDREPORT']) && $content['ISADDSAVEDREPORT'] )
 	}
 
 	//	echo $content['SourceID'];
-	if ( isset($content['Sources'][$content['SourceID']]['ObjRef']) ) 
+	if ( isset($content['SourceID']) && isset($content['Sources'][$content['SourceID']]['ObjRef']) ) 
 	{
 		// Obtain and get the Config Object
 		$stream_config = $content['Sources'][$content['SourceID']]['ObjRef']; 
@@ -997,12 +1026,11 @@ if ( isset($_POST['op']) )
 		if ( isset($_POST['report_customtitle']) ) { $content['customTitle'] = DB_RemoveBadChars($_POST['report_customtitle']); } else {$content['report_customtitle'] = ""; }
 		if ( isset($_POST['report_customcomment']) ) { $content['customComment'] = DB_RemoveBadChars($_POST['report_customcomment']); } else {$content['report_customcomment'] = ""; }
 
-
-//		if ( isset($_POST['report_filterString']) ) { $content['filterString'] = DB_RemoveBadChars($_POST['report_filterString']); } else {$content['report_filterString'] = ""; }
-
-//echo $szFilterString . "!" . $content['filterString'];
-//exit;
-
+		// Check for $content['ERROR_CODE']
+		if ( isset($content['ERROR_CODE']) && $content['ERROR_CODE'] == ERROR_SOURCENOTFOUND ) {
+			// Disable Error Display in this case
+			unset($content['ISERROR']); 
+		}
 
 		if ( isset($_POST['outputFormat']) ) { $content['outputFormat'] = DB_RemoveBadChars($_POST['outputFormat']); }
 		if ( isset($_POST['outputTarget']) ) { $content['outputTarget'] = DB_RemoveBadChars($_POST['outputTarget']); }
