@@ -52,6 +52,14 @@ InitFilterHelpers();	// Helpers for frontend filtering!
 IncludeLanguageFile( $gl_root_path . '/lang/' . $LANG . '/admin.php' );
 // --- 
 
+// --- Deny if DisableAdminUsers is enabled and User is not ADMIN 
+if ( !isset($_SESSION['SESSION_ISADMIN']) || $_SESSION['SESSION_ISADMIN'] == 0 ) 
+{
+	if ( GetConfigSetting("DisableAdminUsers", 0, CFGLEVEL_GLOBAL) == 1 )
+		DieWithFriendlyErrorMsg( $content['LN_ADMIN_ERROR_NOTALLOWED'] );
+}
+// --- 
+
 // --- Deny if User is READONLY!
 if ( !isset($_SESSION['SESSION_ISREADONLY']) || $_SESSION['SESSION_ISREADONLY'] == 1 )
 {
@@ -446,6 +454,9 @@ if ( isset($_POST['op']) )
 				array_splice($content['SUBCOLUMNS'], $iArrayNum-1, 0, $EntryTwoMove);
 			}
 			// --- 
+			
+			// Add Focus to MoveUp Button again
+			AddWindowLoadFocus("subop_moveup_" . $szColId); 
 		}
 		else if ( isset($_POST['subop_movedown']) )
 		{
@@ -476,6 +487,9 @@ if ( isset($_POST['op']) )
 				array_splice($content['SUBCOLUMNS'], $iArrayNum+1, 0, $EntryTwoMove);
 			}
 			// --- 
+
+			// Add Focus to MoveDown Button again
+			AddWindowLoadFocus("subop_movedown_" . $szColId); 
 		}
 		else // Now SUBOP means normal processing!
 		{
