@@ -120,9 +120,8 @@ class CGIFLZW
 
 	///////////////////////////////////////////////////////////////////////////
 
-	// CONSTRUCTOR
-	function CGIFLZW()
-	{
+	// Constructor
+	public function __construct() {
 		$this->MAX_LZW_BITS = 12;
 		unSet($this->Next);
 		unSet($this->Vals);
@@ -134,6 +133,9 @@ class CGIFLZW
 		$this->Stack = range(0, (1 << ($this->MAX_LZW_BITS + 1)) - 1);
 		$this->Buf   = range(0, 279);
 	}
+	function CGIFLZW() {
+		self::__construct(); 
+	}
 
 	///////////////////////////////////////////////////////////////////////////
 
@@ -336,11 +338,13 @@ class CGIFCOLORTABLE
 	///////////////////////////////////////////////////////////////////////////
 
 	// CONSTRUCTOR
-	function CGIFCOLORTABLE()
-	{
+	public function __construct() {
 		unSet($this->m_nColors);
 		unSet($this->m_arColors);
 	}
+	function CGIFCOLORTABLE() {
+		self::__construct(); 
+	}
 
 	///////////////////////////////////////////////////////////////////////////
 
@@ -439,8 +443,7 @@ class CGIFFILEHEADER
 	///////////////////////////////////////////////////////////////////////////
 
 	// CONSTRUCTOR
-	function CGIFFILEHEADER()
-	{
+	public function __construct() {
 		unSet($this->m_lpVer);
 		unSet($this->m_nWidth);
 		unSet($this->m_nHeight);
@@ -452,6 +455,9 @@ class CGIFFILEHEADER
 		unSet($this->m_nPixelRatio);
 		unSet($this->m_colorTable);
 	}
+	function CGIFFILEHEADER() {
+		self::__construct(); 
+	}
 
 	///////////////////////////////////////////////////////////////////////////
 
@@ -515,8 +521,7 @@ class CGIFIMAGEHEADER
 	///////////////////////////////////////////////////////////////////////////
 
 	// CONSTRUCTOR
-	function CGIFIMAGEHEADER()
-	{
+	public function __construct() {
 		unSet($this->m_nLeft);
 		unSet($this->m_nTop);
 		unSet($this->m_nWidth);
@@ -527,6 +532,9 @@ class CGIFIMAGEHEADER
 		unSet($this->m_nTableSize);
 		unSet($this->m_colorTable);
 	}
+	function CGIFIMAGEHEADER() {
+		self::__construct(); 
+	}
 
 	///////////////////////////////////////////////////////////////////////////
 
@@ -584,9 +592,7 @@ class CGIFIMAGE
 	var $m_lzw;
 
 	///////////////////////////////////////////////////////////////////////////
-
-	function CGIFIMAGE()
-	{
+	public function __construct() {
 		unSet($this->m_disp);
 		unSet($this->m_bUser);
 		unSet($this->m_bTrans);
@@ -597,6 +603,9 @@ class CGIFIMAGE
 		$this->m_gih = new CGIFIMAGEHEADER();
 		$this->m_lzw = new CGIFLZW();
 	}
+	function CGIFIMAGE() {
+		self::__construct(); 
+	}
 
 	///////////////////////////////////////////////////////////////////////////
 
@@ -753,13 +762,15 @@ class CGIF
 	///////////////////////////////////////////////////////////////////////////
 
 	// CONSTRUCTOR
-	function CGIF()
-	{
+	public function __construct() {
 		$this->m_gfh     = new CGIFFILEHEADER();
 		$this->m_img     = new CGIFIMAGE();
 		$this->m_lpData  = "";
 		$this->m_bLoaded = false;
 	}
+	function CGIF() {
+		self::__construct(); 
+	}
 
 	///////////////////////////////////////////////////////////////////////////
 
