@@ -58,22 +58,25 @@ class LogStreamDB extends LogStream {
 	private $_previousPageUID = -1;
 	private $_lastPageUID = -1;
 	private $_firstPageUID = -1;
-	private $_currentPageNumber = 0;
+	private $_currentPageNumber = -1;
 
 	private $_SQLwhereClause = "";
 	private $_myDBQuery = null;
 
 	// Constructor
-	public function LogStreamDB($streamConfigObj) {
+	public function __construct ($streamConfigObj) {
 		$this->_logStreamConfigObj = $streamConfigObj;
 
 		if ( $this->_logStreamConfigObj->DBType == DB_MYSQL )
 		{
 			// Probe if a function exists!
-			if ( !function_exists("mysql_connect") )
-				DieWithFriendlyErrorMsg("Error, MYSQL Extensions are not enabled! Function 'mysql_connect' does not exist.");
+			if ( !function_exists("mysqli_connect") )
+				DieWithFriendlyErrorMsg("Error, MYSQL Extensions are not enabled! Function 'mysqli_connect' does not exist.");
 		}
 	}
+	public function LogStreamDB($streamConfigObj) {
+		self::__construct($streamConfigObj);
+	}
 
 	/**
 	* Open and verifies the database conncetion 
@@ -106,7 +109,7 @@ class LogStreamDB extends LogStream {
 			return $res;
 
 		// Success, this means we init the Pagenumber to ONE!
-		$this->_currentPageNumber = 1;
+		// $this->_currentPageNumber = 1;
 		
 		// reached this point means success!
 		return SUCCESS;
@@ -129,7 +132,7 @@ class LogStreamDB extends LogStream {
 	public function Close()
 	{
 		if ($this->_dbhandle) 
-			mysql_close($this->_dbhandle);
+			mysqli_close($this->_dbhandle);
 		$this->_dbhandle = null;
 		return SUCCESS;
 	}
@@ -144,7 +147,7 @@ class LogStreamDB extends LogStream {
 		if ( $this->_dbhandle == null ) 
 		{
 			// Forces to open a new link in all cases!
-			$this->_dbhandle = @mysql_connect($this->_logStreamConfigObj->DBServer,$this->_logStreamConfigObj->DBUser,$this->_logStreamConfigObj->DBPassword, true);
+			$this->_dbhandle = @mysqli_connect($this->_logStreamConfigObj->DBServer,$this->_logStreamConfigObj->DBUser,$this->_logStreamConfigObj->DBPassword);
 			if (!$this->_dbhandle) 
 			{
 				if ( isset($php_errormsg) )
@@ -159,7 +162,7 @@ class LogStreamDB extends LogStream {
 		}
 		
 		// Select the database now!
-		$bRet = @mysql_select_db($this->_logStreamConfigObj->DBName, $this->_dbhandle);
+		$bRet = @mysqli_select_db($this->_dbhandle, $this->_logStreamConfigObj->DBName);
 		if(!$bRet) 
 		{
 			if ( isset($php_errormsg) )
@@ -173,7 +176,7 @@ class LogStreamDB extends LogStream {
 		}
 		
 		// Check if the table exists!
-		$numTables = @mysql_num_rows( mysql_query("SHOW TABLES LIKE '%" . $this->_logStreamConfigObj->DBTableName . "%'"));
+		$numTables = @mysqli_num_rows( mysqli_query($this->_dbhandle, "SHOW TABLES LIKE '%" . $this->_logStreamConfigObj->DBTableName . "%'"));
 		if( $numTables <= 0 )
 			return ERROR_DB_TABLENOTFOUND;
 
@@ -312,7 +315,7 @@ class LogStreamDB extends LogStream {
 				OutputDebugMessage("LogStreamDB|CreateMissingIndexes: Createing missing INDEX for '" . $dbmapping[$szTableType]['DBMAPPINGS'][$myproperty] . "' - " . $szSql, DEBUG_INFO);
 				
 				// Add missing INDEX now!
-				$myQuery = mysql_query($szSql, $this->_dbhandle);
+				$myQuery = mysqli_query($this->_dbhandle, $szSql);
 				if (!$myQuery)
 				{
 					// Return failure!
@@ -410,7 +413,7 @@ class LogStreamDB extends LogStream {
 		OutputDebugMessage("LogStreamDB|CreateMissingTrigger: Creating missing TRIGGER for '" . $szTableName . "' - $szDBTriggerCheckSumField = crc32(NEW.$szDBTriggerField)" . $szSql, DEBUG_INFO);
 		
 		// Add missing INDEX now!
-		$myQuery = mysql_query($szSql, $this->_dbhandle);
+		$myQuery = mysqli_query($this->_dbhandle, $szSql);
 		if (!$myQuery)
 		{
 			// Return failure!
@@ -440,7 +443,7 @@ class LogStreamDB extends LogStream {
 						$dbmapping[$szTableType]['DBMAPPINGS'][MISC_CHECKSUM] . "` INT(11) UNSIGNED NOT NULL DEFAULT '0'"; 
 
 		// Update Table schema now!
-		$myQuery = mysql_query($szUpdateSql, $this->_dbhandle);
+		$myQuery = mysqli_query($this->_dbhandle, $szUpdateSql);
 		if (!$myQuery)
 		{
 			// Return failure!
@@ -465,11 +468,11 @@ class LogStreamDB extends LogStream {
 
 		// Create SQL and Get INDEXES for table!
 		$szSql = "SHOW COLUMNS FROM `" . $this->_logStreamConfigObj->DBTableName . "` WHERE Field = '" . $dbmapping[$szTableType]['DBMAPPINGS'][MISC_CHECKSUM] . "'"; 
-		$myQuery = mysql_query($szSql, $this->_dbhandle);
+		$myQuery = mysqli_query($this->_dbhandle, $szSql);
 		if ($myQuery)
 		{
 			// Get result!
-			$myRow = mysql_fetch_array($myQuery,  MYSQL_ASSOC);
+			$myRow = mysqli_fetch_array($myQuery,  MYSQLI_ASSOC);
 			if (strpos( strtolower($myRow['Type']), "unsigned") === false ) 
 			{
 				// return error code!
@@ -477,7 +480,7 @@ class LogStreamDB extends LogStream {
 			}
 
 			// Free query now
-			mysql_free_result ($myQuery); 
+			mysqli_free_result ($myQuery); 
 
 			// Increment for the Footer Stats 
 			$querycount++;
@@ -683,15 +686,15 @@ class LogStreamDB extends LogStream {
 			return $this->_firstPageUID;
 
 		$szSql = "SELECT MAX(" . $dbmapping[$szTableType]['DBMAPPINGS'][SYSLOG_UID] . ") FROM `" .  $this->_logStreamConfigObj->DBTableName . "` " . $this->_SQLwhereClause;
-		$myQuery = mysql_query($szSql, $this->_dbhandle);
+		$myQuery = mysqli_query($this->_dbhandle, $szSql);
 		if ($myQuery)
 		{
 			// obtain first and only row
-			$myRow = mysql_fetch_row($myQuery);
+			$myRow = mysqli_fetch_row($myQuery);
 			$this->_firstPageUID = $myRow[0];
 
 			// Free query now
-			mysql_free_result ($myQuery); 
+			mysqli_free_result ($myQuery); 
 
 			// Increment for the Footer Stats 
 			$querycount++;
@@ -715,15 +718,15 @@ class LogStreamDB extends LogStream {
 			return $this->_lastPageUID;
 
 		$szSql = "SELECT MIN(" . $dbmapping[$szTableType]['DBMAPPINGS'][SYSLOG_UID] . ") FROM `" .  $this->_logStreamConfigObj->DBTableName . "` " . $this->_SQLwhereClause;
-		$myQuery = mysql_query($szSql, $this->_dbhandle);
+		$myQuery = mysqli_query($this->_dbhandle, $szSql);
 		if ($myQuery)
 		{
 			// obtain first and only row
-			$myRow = mysql_fetch_row($myQuery);
+			$myRow = mysqli_fetch_row($myQuery);
 			$this->_lastPageUID = $myRow[0];
 
 			// Free query now
-			mysql_free_result ($myQuery); 
+			mysqli_free_result ($myQuery); 
 
 			// Increment for the Footer Stats 
 			$querycount++;
@@ -778,11 +781,11 @@ class LogStreamDB extends LogStream {
 		{
 			// Obtain Stats data for this table!
 			$szSql = "SHOW TABLE STATUS FROM `" .  $this->_logStreamConfigObj->DBName . "`"; 
-			$myQuery = mysql_query($szSql, $this->_dbhandle);
+			$myQuery = mysqli_query($this->_dbhandle, $szSql);
 			if ($myQuery)
 			{
 				// Loop through results
-				while ($myRow = mysql_fetch_array($myQuery,  MYSQL_ASSOC))
+				while ($myRow = mysqli_fetch_array($myQuery,  MYSQLI_ASSOC))
 				{
 					// Set tablename!
 					$tableName = $myRow['Name'];
@@ -806,7 +809,7 @@ class LogStreamDB extends LogStream {
 				}
 
 				// Free query now
-				mysql_free_result ($myQuery); 
+				mysqli_free_result ($myQuery); 
 
 				// Increment for the Footer Stats 
 				$querycount++;
@@ -837,15 +840,15 @@ class LogStreamDB extends LogStream {
 		{
 			// SHOW TABLE STATUS FROM
 			$szSql = "SELECT count(" . $dbmapping[$szTableType]['DBMAPPINGS'][SYSLOG_UID] . ") as Counter FROM `" .  $this->_logStreamConfigObj->DBTableName . "`"; 
-			$myQuery = mysql_query($szSql, $this->_dbhandle);
+			$myQuery = mysqli_query($this->_dbhandle, $szSql);
 			if ($myQuery)
 			{
 				// Obtain RowCount!
-				$myRow		= mysql_fetch_row($myQuery); 
+				$myRow		= mysqli_fetch_row($myQuery); 
 				$rowcount = $myRow[0];
 
 				// Free query now
-				mysql_free_result ($myQuery); 
+				mysqli_free_result ($myQuery); 
 
 				// Increment for the Footer Stats 
 				$querycount++;
@@ -900,24 +903,24 @@ class LogStreamDB extends LogStream {
 			// DELETE DATA NOW!
 			$szSql = "DELETE FROM `" .  $this->_logStreamConfigObj->DBTableName . "`" . $szWhere; 
 			OutputDebugMessage("LogStreamDB|CleanupLogdataByDate: Created SQL Query:<br>" . $szSql, DEBUG_DEBUG);
-			$myQuery = mysql_query($szSql, $this->_dbhandle);
+			$myQuery = mysqli_query($this->_dbhandle, $szSql);
 			if ($myQuery)
 			{
 				// Get affected rows and return!
-				$rowcount = mysql_affected_rows();
+				$rowcount = mysqli_affected_rows($this->_dbhandle);
 				
 				// Reset AUTO_INCREMENT if all records were deleted!
 				if ( $nDateTimeStamp == 0 ) 
 				{
 					$szSql = "ALTER TABLE " . $this->_logStreamConfigObj->DBTableName . " AUTO_INCREMENT=0";
-					$myQuery = mysql_query($szSql, $this->_dbhandle);
+					$myQuery = mysqli_query($this->_dbhandle, $szSql);
 					// error occured, output DEBUG message
 					if (!$myQuery)
 						$this->PrintDebugError("CleanupLogdataByDate failed to reset AUTO_INCREMENT for '" . $this->_logStreamConfigObj->DBTableName . "' table. ");
 				}
 
 				// Free result not needed here!
-				//mysql_free_result ($myQuery); 
+				//mysqli_free_result ($myQuery); 
 			}
 			else
 			{
@@ -950,11 +953,11 @@ class LogStreamDB extends LogStream {
 		OutputDebugMessage("LogStreamDB|UpdateAllMessageChecksum: Running Created SQL Query:<br>" . $szSql, DEBUG_ULTRADEBUG);
 		
 		// Running SQL Query
-		$myQuery = mysql_query($szSql, $this->_dbhandle);
+		$myQuery = mysqli_query($this->_dbhandle, $szSql);
 		if ($myQuery)
 		{
 			// Debug Output
-			OutputDebugMessage("LogStreamDB|UpdateAllMessageChecksum: Successfully updated Checksum of '" . mysql_affected_rows($this->_dbhandle) . "' datarecords", DEBUG_INFO);
+			OutputDebugMessage("LogStreamDB|UpdateAllMessageChecksum: Successfully updated Checksum of '" . mysqli_affected_rows($this->_dbhandle) . "' datarecords", DEBUG_INFO);
 
 			// Return success
 			return SUCCESS; 
@@ -986,7 +989,7 @@ class LogStreamDB extends LogStream {
 			$szSql =	"UPDATE " . $this->_logStreamConfigObj->DBTableName . 
 						" SET " . $dbmapping[$szTableType]['DBMAPPINGS'][MISC_CHECKSUM] . " = " . $arrProperitesIn[MISC_CHECKSUM] . 
 						" WHERE " . $dbmapping[$szTableType]['DBMAPPINGS'][SYSLOG_UID] . " = " . $arrProperitesIn[SYSLOG_UID]; 
-			$myQuery = mysql_query($szSql, $this->_dbhandle);
+			$myQuery = mysqli_query($this->_dbhandle, $szSql);
 			if ($myQuery)
 			{
 				// Return success
@@ -1050,7 +1053,7 @@ class LogStreamDB extends LogStream {
 		if ( $nConsFieldType == FILTER_TYPE_DATE )
 		{
 			// Helper variable for the select statement
-			$mySelectFieldName = $myDBGroupByFieldName . "Grouped";
+			$mySelectFieldName = $myDBGroupByFieldName . "grouped";
 			$myDBQueryFieldName = "DATE( " . $myDBConsFieldName . ") AS " . $myDBGroupByFieldName ;
 		}
 
@@ -1082,16 +1085,21 @@ class LogStreamDB extends LogStream {
 		OutputDebugMessage("LogStreamDB|ConsolidateItemListByField: Running Created SQL Query:<br>" . $szSql, DEBUG_ULTRADEBUG);
 
 		// Perform Database Query
-		$myquery = mysql_query($szSql, $this->_dbhandle);
-		if ( !$myquery ) 
+		$myquery = mysqli_query($this->_dbhandle, $szSql);
+		if ( !$myquery ) {
+			$this->PrintDebugError("Invalid SQL: ".$szSql);
 			return ERROR_DB_QUERYFAILED;
+		}
 		
 		// Initialize Array variable
 		$aResult = array();
 
 		// read data records
-		while ($myRow = mysql_fetch_array($myquery,  MYSQL_ASSOC))
+		while ($myRow = mysqli_fetch_array($myquery,  MYSQLI_ASSOC))
 		{
+			// Keys need to be converted into lowercase!
+			$myRow = array_change_key_case($myRow, CASE_LOWER);
+
 			// Create new row
 			$aNewRow = array();
 
@@ -1189,7 +1197,7 @@ class LogStreamDB extends LogStream {
 		if ( $nConsFieldType == FILTER_TYPE_DATE )
 		{
 			// Helper variable for the select statement
-			$mySelectFieldName = $myDBGroupByFieldName . "Grouped";
+			$mySelectFieldName = $myDBGroupByFieldName . "grouped";
 			$myDBQueryFieldName = "DATE( " . $myDBConsFieldName . ") AS " . $myDBGroupByFieldName ;
 		}
 
@@ -1221,16 +1229,21 @@ class LogStreamDB extends LogStream {
 		OutputDebugMessage("LogStreamDB|ConsolidateDataByField: Running Created SQL Query:<br>" . $szSql, DEBUG_ULTRADEBUG);
 
 		// Perform Database Query
-		$myquery = mysql_query($szSql, $this->_dbhandle);
-		if ( !$myquery ) 
+		$myquery = mysqli_query($this->_dbhandle, $szSql);
+		if ( !$myquery ) {
+			$this->PrintDebugError("Invalid SQL: ".$szSql);
 			return ERROR_DB_QUERYFAILED;
+		}
 
 		// Initialize Array variable
 		$aResult = array();
 
 		// read data records
-		while ($myRow = mysql_fetch_array($myquery,  MYSQL_ASSOC))
+		while ($myRow = mysqli_fetch_array($myquery,  MYSQLI_ASSOC))
 		{
+			// Keys need to be converted into lowercase!
+			$myRow = array_change_key_case($myRow, CASE_LOWER);
+
 			// Create new row
 			$aNewRow = array();
 
@@ -1238,14 +1251,6 @@ class LogStreamDB extends LogStream {
 			{
 				$myFieldID = $this->GetFieldIDbyDatabaseMapping($szTableType, $myFieldName); 
 				$aNewRow[ $myFieldID ] = $myFieldValue;
-
-/*				if ( $myFieldName == $dbmapping[$szTableType]['DBMAPPINGS'][$szConsFieldId] )
-					$aNewRow[$szConsFieldId] = $myFieldValue;
-				else
-				{
-					$aNewRow[$myFieldName] = $myFieldValue;
-*/
-//				}
 			}
 			// Add new row to result
 			$aResult[] = $aNewRow;
@@ -1283,7 +1288,7 @@ class LogStreamDB extends LogStream {
 			if ( $nFieldType == FILTER_TYPE_DATE )
 			{
 				// Helper variable for the select statement
-				$mySelectFieldName = $mySelectFieldName . "Grouped";
+				$mySelectFieldName = $mySelectFieldName . "grouped";
 				$myDBQueryFieldName = "DATE( " . $myDBFieldName . ") AS " . $mySelectFieldName ;
 			}
 
@@ -1298,24 +1303,32 @@ class LogStreamDB extends LogStream {
 			// Create SQL String now!
 			$szSql =	"SELECT " . 
 						$myDBQueryFieldName . ", " . 
-						"count(" . $myDBFieldName . ") as TotalCount " . 
+						"count(" . $myDBFieldName . ") as totalcount " . 
 						" FROM `" . $this->_logStreamConfigObj->DBTableName . "`" . 
 						$this->_SQLwhereClause . 
 						" GROUP BY " . $mySelectFieldName . 
-						" ORDER BY TotalCount DESC" . 
+						" ORDER BY totalcount DESC" . 
 						" LIMIT " . $nRecordLimit;
 
 			// Perform Database Query
-			$myquery = mysql_query($szSql, $this->_dbhandle);
-			if ( !$myquery ) 
+			$myquery = mysqli_query($this->_dbhandle, $szSql);
+			if ( !$myquery ) {
+				$this->PrintDebugError("Invalid SQL: ".$szSql);
 				return ERROR_DB_QUERYFAILED;
+			}
 			
 			// Initialize Array variable
 			$aResult = array();
 
 			// read data records
-			while ($myRow = mysql_fetch_array($myquery,  MYSQL_ASSOC))
-				$aResult[ $myRow[$mySelectFieldName] ] = $myRow['TotalCount'];
+			while ($myRow = mysqli_fetch_array($myquery,  MYSQLI_ASSOC))
+			{
+				// Keys need to be converted into lowercase!
+				$myRow = array_change_key_case($myRow, CASE_LOWER);
+
+				// Set totalcount Result
+				$aResult[ $myRow[$mySelectFieldName] ] = $myRow['totalcount'];
+			}
 
 			// return finished array
 			if ( count($aResult) > 0 )
@@ -1589,7 +1602,7 @@ class LogStreamDB extends LogStream {
 		if ( $this->_myDBQuery != null )
 		{
 			// Free Query ressources
-			mysql_free_result ($this->_myDBQuery); 
+			mysqli_free_result ($this->_myDBQuery); 
 			$this->_myDBQuery = null;
 		}
 
@@ -1616,13 +1629,13 @@ class LogStreamDB extends LogStream {
 		
 		// Copy rows into the buffer!
 		$iBegin = $this->_currentRecordNum;
-		while ($myRow = mysql_fetch_array($this->_myDBQuery,  MYSQL_ASSOC))
+		while ($myRow = mysqli_fetch_array($this->_myDBQuery,  MYSQLI_ASSOC))
 		{
 			// Check if result was successfull!
 			if ( $myRow === FALSE || !$myRow  )
 				break;
 			
-			// Keys will be converted into lowercase!
+			// Keys need to be converted into lowercase!
 			$this->bufferedRecords[$iBegin] = array_change_key_case($myRow, CASE_LOWER);
 			$iBegin++;
 		}
@@ -1633,7 +1646,7 @@ class LogStreamDB extends LogStream {
 		// --- 
 
 		// Free Query ressources
-//		mysql_free_result ($myquery); 
+//		mysqli_free_result ($myquery); 
 
 		// Only obtain count if enabled and not done before
 		if ( $this->_logStreamConfigObj->DBEnableRowCounting && $this->_totalRecordCount == -1 ) 
@@ -1666,18 +1679,17 @@ class LogStreamDB extends LogStream {
 		// ---
 
 		// Perform Database Query
-		$this->_myDBQuery = mysql_query($szSql, $this->_dbhandle);
+		$this->_myDBQuery = mysqli_query($this->_dbhandle, $szSql);
 		if ( !$this->_myDBQuery ) 
 		{
 			// Check if a field is missing!
-			if ( mysql_errno() == 1054 ) 
+			if ( mysqli_errno($this->_dbhandle) == 1054 ) 
 			{
 				// Handle missing field and try again!
 				if ( $this->HandleMissingField() == SUCCESS ) 
 				{
-					$this->_myDBQuery = mysql_query($szSql, $this->_dbhandle);
-					if ( !$this->_myDBQuery ) 
-					{
+					$this->_myDBQuery = mysqli_query($this->_dbhandle, $szSql);
+					if ( !$this->_myDBQuery ) {
 						$this->PrintDebugError("Invalid SQL: ".$szSql);
 						return ERROR_DB_QUERYFAILED;
 					}
@@ -1697,7 +1709,7 @@ class LogStreamDB extends LogStream {
 			if ( $this->_currentRecordStart > 0 ) 
 			{
 				// Throw away 
-				$myRow = mysql_fetch_array($this->_myDBQuery,  MYSQL_ASSOC);
+				$myRow = mysqli_fetch_array($this->_myDBQuery,  MYSQLI_ASSOC);
 			}
 		}
 
@@ -1796,8 +1808,8 @@ class LogStreamDB extends LogStream {
 	{
 		global $extraErrorDescription; 
 
-		$errdesc = mysql_error();
-		$errno = mysql_errno();
+		$errdesc = mysqli_error($this->_dbhandle);
+		$errno = mysqli_errno($this->_dbhandle);
 
 		$errormsg="$szErrorMsg <br>";
 		$errormsg.="Detail error: $errdesc <br>";
@@ -1815,10 +1827,10 @@ class LogStreamDB extends LogStream {
 	*/
 	private function GetRowCountByString($szQuery)
 	{
-		if ($myQuery = mysql_query($szQuery)) 
+		if ($myQuery = mysqli_query($this->_dbhandle, $szQuery)) 
 		{   
-			$num_rows = mysql_num_rows($myQuery);
-			mysql_free_result ($myQuery); 
+			$num_rows = mysqli_num_rows($myQuery);
+			mysqli_free_result ($myQuery); 
 		}
 		return $num_rows;
 	}
@@ -1828,7 +1840,7 @@ class LogStreamDB extends LogStream {
 	*/
 	private function GetRowCountByQueryID($myQuery)
 	{
-		$num_rows = mysql_num_rows($myQuery);
+		$num_rows = mysqli_num_rows($myQuery);
 		return $num_rows;
 	}
 
@@ -1837,10 +1849,10 @@ class LogStreamDB extends LogStream {
 	*/
 	private function GetRowCountFromTable()
 	{
-		if ( $myquery = mysql_query("Select FOUND_ROWS();", $this->_dbhandle) ) 
+		if ( $myquery = mysqli_query($this->_dbhandle, "Select FOUND_ROWS();") ) 
 		{
 			// Get first and only row!
-			$myRow = mysql_fetch_array($myquery);
+			$myRow = mysqli_fetch_array($myquery);
 			
 			// copy row count
 			$numRows = $myRow[0];
@@ -1850,28 +1862,6 @@ class LogStreamDB extends LogStream {
 
 		// return result!
 		return $numRows;
-
-		/* OLD slow code!
-		global $dbmapping,$querycount;
-		$szTableType = $this->_logStreamConfigObj->DBTableType;
-
-		// Create Statement and perform query!
-		$szSql = "SELECT count(" . $dbmapping[$szTableType][SYSLOG_UID] . ") FROM " . $this->_logStreamConfigObj->DBTableName . $this->_SQLwhereClause;
-		if ($myQuery = mysql_query($szSql, $this->_dbhandle)) 
-		{
-			// obtain first and only row
-			$myRow = mysql_fetch_row($myQuery);
-			$numRows = $myRow[0];
-
-			// Increment for the Footer Stats 
-			$querycount++;
-
-			// Free query now
-			mysql_free_result ($myQuery); 
-		}
-		else
-			$numRows = -1;
-		*/
 	}
 
 	/*
@@ -1882,7 +1872,7 @@ class LogStreamDB extends LogStream {
 		global $dbmapping, $fields;
 
 		// Get Err description
-		$errdesc = mysql_error();
+		$errdesc = mysqli_error($this->_dbhandle);
 		
 		// Try to get missing field from SQL Error of not specified as argument
 		if ( $szMissingField == null ) 
@@ -1925,7 +1915,7 @@ class LogStreamDB extends LogStream {
 				if ( strlen($szUpdateSql) > 0 )
 				{
 					// Update Table schema now!
-					$myQuery = mysql_query($szUpdateSql, $this->_dbhandle);
+					$myQuery = mysqli_query($this->_dbhandle, $szUpdateSql);
 					if (!$myQuery)
 					{
 						// Return failure!
@@ -1963,18 +1953,18 @@ class LogStreamDB extends LogStream {
 
 		// Create SQL and Get INDEXES for table!
 		$szSql = "SHOW INDEX FROM `" .  $this->_logStreamConfigObj->DBTableName . "`"; 
-		$myQuery = mysql_query($szSql, $this->_dbhandle);
+		$myQuery = mysqli_query($this->_dbhandle, $szSql);
 		if ($myQuery)
 		{
 			// Loop through results
-			while ($myRow = mysql_fetch_array($myQuery,  MYSQL_ASSOC))
+			while ($myRow = mysqli_fetch_array($myQuery,  MYSQLI_ASSOC))
 			{
 				// Add to index keys
 				$arrIndexKeys[] = strtolower($myRow['Key_name']); 
 			}
 
 			// Free query now
-			mysql_free_result ($myQuery); 
+			mysqli_free_result ($myQuery); 
 
 			// Increment for the Footer Stats 
 			$querycount++;
@@ -2002,18 +1992,18 @@ class LogStreamDB extends LogStream {
 
 		// Create SQL and Get INDEXES for table!
 		$szSql = "SHOW FIELDS FROM `" .  $this->_logStreamConfigObj->DBTableName . "`"; 
-		$myQuery = mysql_query($szSql, $this->_dbhandle);
+		$myQuery = mysqli_query($this->_dbhandle, $szSql);
 		if ($myQuery)
 		{
 			// Loop through results
-			while ($myRow = mysql_fetch_array($myQuery,  MYSQL_ASSOC))
+			while ($myRow = mysqli_fetch_array($myQuery,  MYSQLI_ASSOC))
 			{
 				// Add to index keys
 				$arrFieldKeys[] = strtolower($myRow['Field']); 
 			}
 
 			// Free query now
-			mysql_free_result ($myQuery); 
+			mysqli_free_result ($myQuery); 
 
 			// Increment for the Footer Stats 
 			$querycount++;
@@ -2041,11 +2031,11 @@ class LogStreamDB extends LogStream {
 
 		// Create SQL and Get INDEXES for table!
 		$szSql = "SHOW TRIGGERS"; 
-		$myQuery = mysql_query($szSql, $this->_dbhandle);
+		$myQuery = mysqli_query($this->_dbhandle, $szSql);
 		if ($myQuery)
 		{
 			// Loop through results
-			while ($myRow = mysql_fetch_array($myQuery,  MYSQL_ASSOC))
+			while ($myRow = mysqli_fetch_array($myQuery,  MYSQLI_ASSOC))
 			{
 //				print_r (  $myRow ); 
 				// Add to index keys
@@ -2053,7 +2043,7 @@ class LogStreamDB extends LogStream {
 			}
 
 			// Free query now
-			mysql_free_result ($myQuery); 
+			mysqli_free_result ($myQuery); 
 
 			// Increment for the Footer Stats 
 			$querycount++;
