@@ -56,7 +56,7 @@ class LogStreamMongoDB extends LogStream {
 	private $_previousPageUID = -1;
 	private $_lastPageUID = -1;
 	private $_firstPageUID = -1;
-	private $_currentPageNumber = 0;
+	private $_currentPageNumber = -1;
 
 	private $_SQLwhereClause = "";
 	private $_myDBQuery = null;
@@ -68,13 +68,16 @@ class LogStreamMongoDB extends LogStream {
 	private $_myMongoQuery = null; 
 
 	// Constructor
-	public function LogStreamMongoDB($streamConfigObj) {
+	public function __construct ($streamConfigObj) {
 		$this->_logStreamConfigObj = $streamConfigObj;
 
 		// Probe if a function exists!
 		if ( !function_exists("bson_encode") )
 			DieWithFriendlyErrorMsg("Error, MongoDB PHP Driver Extensions is not installed! Please see <a href\"http://www.php.net/manual/en/mongo.installation.php\">http://www.php.net/manual/en/mongo.installation.php</a> for installation details.");
 	}
+	public function LogStreamMongoDB($streamConfigObj) {
+		self::__construct($streamConfigObj);
+	}
 
 	/**
 	* Open and verifies the database conncetion 
@@ -113,7 +116,7 @@ class LogStreamMongoDB extends LogStream {
 //			return $res;
 
 		// Success, this means we init the Pagenumber to ONE!
-		$this->_currentPageNumber = 1;
+//		$this->_currentPageNumber = 1;
 		
 		// reached this point means success!
 		return SUCCESS;
