@@ -62,9 +62,7 @@ class Report_syslogsummary extends Report {
 	private $_colorThreshold = 10;								// Threshold for coloured display of Eventcounter
 
 	// Constructor
-	public function Report_syslogsummary() {
-//		$this->_logStreamConfigObj = $streamConfigObj;
-
+	public function __construct () {
 		// Fill fields we need for this report
 		$this->_arrProperties[] = SYSLOG_UID;
 		$this->_arrProperties[] = SYSLOG_DATE;
@@ -104,9 +102,9 @@ class Report_syslogsummary extends Report {
 														'MinValue'		=> 1,
 /*														'MaxValue'		=> 0,*/
 												); 
-
-		
-
+	}
+	public function Report_syslogsummary() {
+		self::__construct();
 	}
 
 	/**
@@ -156,7 +154,6 @@ class Report_syslogsummary extends Report {
 				{
 					$tmpReportData['DisplayName'] = $this->GetSeverityDisplayName( $tmpReportData[SYSLOG_SEVERITY] );
 					$tmpReportData['bgcolor'] = $this->GetSeverityBGColor( $tmpReportData[SYSLOG_SEVERITY] ); // $severity_colors[ $tmpReportData[SYSLOG_SEVERITY] ];
-
 					$iTotalEvents += $tmpReportData['itemcount']; 
 				}
 
@@ -181,8 +178,10 @@ class Report_syslogsummary extends Report {
 			if ( is_array($content["report_computers"]) && count($content["report_computers"]) > 0 )
 			{
 				// Create plain hosts list for Consolidate function
-				foreach ( $content["report_computers"] as $tmpComputer ) 
+				foreach ( $content["report_computers"] as $tmpComputer ) {
 					$arrHosts[] = $tmpComputer[SYSLOG_HOST]; 
+					$tmpComputer[SYSLOG_HOST] = htmlspecialchars($tmpComputer[SYSLOG_HOST]); // XSS Fix: Remove HTML Characters!
+				}
 			}
 			else
 				return ERROR_REPORT_NODATA; 
@@ -358,7 +357,7 @@ class Report_syslogsummary extends Report {
 				$this->_streamObj->AppendFilter( $fields[SYSLOG_HOST]['SearchField'] . ":=" . $myHost ); 
 
 				// Set Host Item Basics if not set yet
-				$content["report_consdata"][ $myHost ][SYSLOG_HOST] = $myHost; 
+				$content["report_consdata"][ $myHost ][SYSLOG_HOST] = htmlspecialchars($myHost); // XSS Fix: Remove HTML Characters!
 
 				// Get Data for single host
 				$content["report_consdata"][ $myHost ]['cons_msgs'] = $this->_streamObj->ConsolidateDataByField( MISC_CHECKSUM, $this->_maxMsgsPerHost, MISC_CHECKSUM, SORTING_ORDER_DESC, null, true, true );
@@ -369,9 +368,9 @@ class Report_syslogsummary extends Report {
 					foreach ( $content["report_consdata"][ $myHost ]['cons_msgs'] as &$myConsData )
 					{
 						// Set Basic data entries
-						if (!isset( $content['filter_facility_list'][$myConsData[SYSLOG_FACILITY]] )) 
+						if (!isset($myConsData[SYSLOG_FACILITY]) || !isset( $content['filter_facility_list'][$myConsData[SYSLOG_FACILITY]] )) 
 							$myConsData[SYSLOG_FACILITY] = SYSLOG_LOCAL0; // Set default in this case
-						if (!isset( $content['filter_severity_list'][$myConsData[SYSLOG_SEVERITY]] )) 
+						if (!isset($myConsData[SYSLOG_SEVERITY]) || !isset( $content['filter_severity_list'][$myConsData[SYSLOG_SEVERITY]] )) 
 							$myConsData[SYSLOG_SEVERITY] = SYSLOG_NOTICE; // Set default in this case
 					}
 				}
@@ -435,6 +434,7 @@ class Report_syslogsummary extends Report {
 					$tmpMyEvent['syslogfacility_text'] = $this->GetFacilityDisplayName($tmpMyEvent['syslogfacility']); //$content['filter_facility_list'][ $tmpMyEvent['syslogfacility'] ]["DisplayName"]; 
 					$tmpMyEvent['syslogseverity_bgcolor'] = $this->GetSeverityBGColor($tmpMyEvent['syslogseverity']); 
 					$tmpMyEvent['syslogfacility_bgcolor'] = $this->GetSeverityBGColor($tmpMyEvent['syslogfacility']);
+					$tmpMyEvent['htmlmsg'] = htmlspecialchars($tmpMyEvent[SYSLOG_MESSAGE]); // XSS Fix: Remove HTML Characters!
 				}
 			}
 			// --- 
