@@ -70,6 +70,14 @@ if ( isset($_GET['uid']) )
 else
 	$content['uid_current'] = UID_UNKNOWN;
 
+// Helper variable to decide if header and footer has to be included
+$content['layout'] = "full"; 
+if ( isset($_GET['layout']) ) 
+{
+	if ( $_GET['layout'] == "naked" )
+		$content['layout'] = "naked"; 
+}
+
 // Copy UID for later use ...
 $content['uid_fromgetrequest'] = $content['uid_current'];
 
@@ -203,10 +211,14 @@ if ( isset($content['Sources'][$currentSourceID]) ) // && $content['uid_current'
 	//				$content['fields'][$mycolkey]['FieldValue'] = $logArray[$mycolkey];
 
 					// --- Set CSS Class
-					if ( $counter % 2 == 0 )
+					if ( $counter % 2 == 0 ) {
 						$content['fields'][$mycolkey]['cssclass'] = "line1";
-					else
+						$content['fields'][$mycolkey]['cssclassfont'] = "line1";
+					}
+					else {
 						$content['fields'][$mycolkey]['cssclass'] = "line2";
+						$content['fields'][$mycolkey]['cssclassfont'] = "line2";
+					}
 
 					if ( $mycolkey == SYSLOG_MESSAGE )
 						$content['fields'][$mycolkey]['menucssclass'] = "cellmenu1_naked";
