@@ -5,11 +5,9 @@
 	* -----------------------------------------------------------------	*
 	* Common needed functions											*
 	*																	*
-	* -> 		*
-	*																	*
 	* All directives are explained within this file						*
 	*
-	* Copyright (C) 2008-2012 Adiscon GmbH.
+	* Copyright (C) 2008-2014 Adiscon GmbH.
 	*
 	* This file is part of LogAnalyzer.
 	*
@@ -40,6 +38,7 @@ if ( !defined('IN_PHPLOGCON') )
 // --- 
 
 // --- Basic Includes
+require_once($gl_root_path . 'include/constants_errors.php');
 include_once($gl_root_path . 'include/constants_general.php');
 include_once($gl_root_path . 'include/constants_logstream.php');
 
@@ -66,7 +65,7 @@ $LANG_EN = "en";	// Used for fallback
 $LANG = "en";		// Default language
 
 // Default Template vars
-$content['BUILDNUMBER'] = "3.6.6";
+$content['BUILDNUMBER'] = "4.1.5";
 $content['UPDATEURL'] = "http://loganalyzer.adiscon.com/files/version.txt";
 $content['TITLE'] = "Adiscon LogAnalyzer :: Release " . $content['BUILDNUMBER'];	// Default page title 
 $content['BASEPATH'] = $gl_root_path;
@@ -703,6 +702,7 @@ function InitFrontEndVariables()
 {
 	global $content;
 
+	$content['IMG_SPACER'] = $content['BASEPATH'] . "images/spacer.gif";
 	$content['MENU_FOLDER_OPEN'] = $content['BASEPATH'] . "images/icons/folder_closed.png";
 	$content['MENU_FOLDER_CLOSED'] = $content['BASEPATH'] . "images/icons/folder.png";
 	$content['MENU_HOMEPAGE'] = $content['BASEPATH'] . "images/icons/home.png";
@@ -855,7 +855,6 @@ function InitConfigurationValues()
 			
 			if ( !$content['SESSION_LOGGEDIN'] ) 
 			{
-
 				// Check if user needs to be logged in
 				if ( GetConfigSetting("UserDBLoginRequired", false) )
 				{
@@ -872,6 +871,15 @@ function InitConfigurationValues()
 					DieWithFriendlyErrorMsg( "You need to be logged in in order to access the admin pages.", "login.php", "Click here to login" );
 				}
 			}
+			else
+			{	
+				// Set Admin Panel Button Status
+				if ( $content['SESSION_ISADMIN'] == 0) 
+				{
+					if ( GetConfigSetting("DisableAdminUsers", 0, CFGLEVEL_GLOBAL) == 1)
+						$content['SHOW_ADMINPANEL'] = "false"; 
+				}
+			}
 
 			// Load field definitions from DB, very first thing todo!
 			LoadFieldsFromDatabase();
@@ -890,8 +898,6 @@ function InitConfigurationValues()
 
 			// Load Configured Sources
 			LoadSourcesFromDatabase();
-
-
 		}
 		else
 		{
@@ -900,8 +906,11 @@ function InitConfigurationValues()
 		}
 	}
 
-	// --- Language Handling
+	// --- Init Fonttype and size by config setting
+	InitFontSettings(); 
+	// ---
 
+	// --- Language Handling
 	// Set gen language default
 	$content['gen_lang'] = GetConfigSetting("ViewDefaultLanguage", "en", CFGLEVEL_GLOBAL); 
 	
@@ -913,11 +922,19 @@ function InitConfigurationValues()
 	}
 	else if ( isset($content['gen_lang']) && VerifyLanguage($content['gen_lang']))
 	{
-		$content['user_lang'] = $content['gen_lang'];
-		$LANG = $content['user_lang'];
+		// Get use language
+		$content['user_lang'] = GetConfigSetting("ViewDefaultLanguage", "en", CFGLEVEL_USER); 
+		if ( isset($content['user_lang']) )
+			$LANG = $content['user_lang'];
+		else
+		{
+			$content['user_lang'] = $content['gen_lang'];
+			$LANG = $content['user_lang'];
+		}
 	}
 	else	// Failsave!
 	{
+		// Get use language
 		$content['user_lang'] = GetConfigSetting("ViewDefaultLanguage", "en", CFGLEVEL_USER) /*"en"*/;
 		$LANG = $content['user_lang'];
 		$content['gen_lang'] = $content['user_lang'];
@@ -947,9 +964,11 @@ function InitConfigurationValues()
 	else
 		$content['user_theme'] = $content['web_theme'];
 
+/*
 	// Init Theme About Info ^^
 	InitThemeAbout($content['user_theme']);
 	// ---
+*/
 
 	// --- Handle HTML Injection stuff
 	if ( strlen(GetConfigSetting("InjectHtmlHeader", false)) > 0 ) 
@@ -1106,7 +1125,7 @@ function DieWithErrorMsg( $szerrmsg )
 
 function DieWithFriendlyErrorMsg( $szerrmsg, $szLink = "", $szLinkLable = "" )
 {
-	global $RUNMODE, $content, $gl_root_path;
+	global $RUNMODE, $content, $gl_root_path, $DEBUGMODE;
 	if		( $RUNMODE == RUNMODE_COMMANDLINE )
 	{
 		print("\n\n\t\tError occured\n");
@@ -1123,10 +1142,16 @@ function DieWithFriendlyErrorMsg( $szerrmsg, $szLink = "", $szLinkLable = "" )
 			"<td class=\"PriorityWarning\" align=\"center\" colspan=\"2\">" . 
 			"<H3>Error occured</H3>" . 
 			"</td></tr>" . 
-			"<tr><td class=\"cellmenu1_naked\" align=\"left\">Errordetails:</td>" . 
+			"<tr><td class=\"cellmenu1_naked\" align=\"left\">Error:</td>" . 
 			"<td class=\"tableBackground\" align=\"left\"><br>" .
 			$szerrmsg . 
 			"<br><br></td></tr>"; 
+		if ( GetConfigSetting("MiscShowDebugMsg", 0, CFGLEVEL_USER) == 1 && isset($content['detailederror']) && strlen($content['detailederror']) > 0) {
+			echo "<tr><td class=\"cellmenu1_naked\" align=\"left\">Details:</td>" . 
+			"<td class=\"tableBackground\" align=\"left\"><br>" .
+			$content['detailederror'] . 
+			"<br><br></td></tr>"; 
+		}
 		if ( strlen($szLink) > 0 && strlen($szLinkLable) > 0 )
 			echo "<tr><td class=\"tableBackground\" align=\"center\" colspan=\"2\"><a href=\"$gl_root_path$szLink\" target=\"\">$szLinkLable</a></tr></td>";
 		echo 
@@ -1174,6 +1199,13 @@ function ReplaceLineBreaksInString($myStr)
 	return str_replace( "\n", "<br>", $myStr );
 }
 
+function EscapeQuotesFromString($myStr)
+{
+//	return htmlspecialchars($myStr, ENT_QUOTES);
+
+	return str_replace( array( "'", "\""), array ("\\x27", "\\x22"), $myStr );
+}
+
 function GetStringWithHTMLCodes($myStr)
 {
 	global $content; 
@@ -1445,9 +1477,9 @@ function GetMonthFromString($szMonth)
 }
 
 /*
-*	AddContextLinks
+*	AddContextHighlights
 */
-function AddContextLinks(&$sourceTxt)
+function AddContextHighlights(&$sourceTxt)
 {
 	global $szTLDDomains;
 
@@ -1455,7 +1487,8 @@ function AddContextLinks(&$sourceTxt)
 	if ( GetConfigSetting("EnableIPAddressResolve", 0, CFGLEVEL_USER) == 1 )
 	{
 		// Search for IP's and Add Reverse Lookup first!
-		$sourceTxt = preg_replace( '/([^\[])\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b/ie', "'\\1\\2.\\3.\\4.\\5' . ReverseResolveIP('\\2.\\3.\\4.\\5', '<font class=\"highlighted\"> {', '} </font>')", $sourceTxt );
+		// oldcode ! $sourceTxt = preg_replace( '/([^\[])\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b/ie', "'\\1\\2.\\3.\\4.\\5' . ReverseResolveIP('\\2.\\3.\\4.\\5', '<font class=\"highlighted\"> {', '} </font>')", $sourceTxt );
+		$sourceTxt = preg_replace_callback( '/([^\[])\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b/i', 'ReverseResolveIP', $sourceTxt );
 	}
 
 	// check if user disabled Context Links. 
@@ -1469,31 +1502,72 @@ function AddContextLinks(&$sourceTxt)
 	// Create Search Array
 	$search = array 
 				(
-					'/\.([\w\d\_\-]+)\.(' . $szTLDDomains . ')([^a-zA-Z0-9\.])/ie',
-/* (?:127)| */		'/(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)/ie',
+					'/\.([\w\d\_\-]+)\.(' . $szTLDDomains . ')([^a-zA-Z0-9\.])/i',
+					'/(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)/i',
 				);
 
 	// Create Replace Array
 	$replace = array 
 				(
-					"'.' . InsertLookupLink(\"\", \"\\1.\\2\", \"\", \"\\3\")",
-					"InsertLookupLink(\"\\1.\\2.\\3.\\4\", \"\", \"\", \"\")", 
+					".<font class=\"highlighted\">\\1.\\2</font>\\3",
+					"<font class=\"highlighted\">\\1.\\2.\\3.\\4</font>", 
 				);
 	
 	// Replace and return!
 	$sourceTxt = preg_replace( $search, $replace, $sourceTxt );
-
-//echo $outTxt . " <br>" ;
-//return $outTxt;
 }
 
+/*
+*	AddContextLinks
+*/
+function AddContextLinks(&$sourceTxt)
+{
+	global $szTLDDomains;
+
+	// Return if not enabled!
+	if ( GetConfigSetting("EnableIPAddressResolve", 0, CFGLEVEL_USER) == 1 )
+	{
+		// Search for IP's and Add Reverse Lookup first!
+		// $sourceTxt = preg_replace( '/([^\[])\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b/ie', "'\\1\\2.\\3.\\4.\\5' . ReverseResolveIP('\\2.\\3.\\4.\\5', '<font class=\"highlighted\"> {', '} </font>')", $sourceTxt );
+		$sourceTxt = preg_replace_callback( '/([^\[])\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b/i', "ReverseResolveIP", $sourceTxt );
+	}
+
+	// check if user disabled Context Links. 
+	if ( GetConfigSetting("EnableContextLinks", 1, CFGLEVEL_USER) == 0 )
+		return; 
+
+	// Create if not set!
+	if ( !isset($szTLDDomains) )
+		CreateTopLevelDomainSearch();
+
+	// Replace and return!
+	$sourceTxt = preg_replace_callback( '/\.([\w\d\_\-]+)\.(' . $szTLDDomains . ')([^a-zA-Z0-9\.])/i', "InsertLookupLinkDomain", $sourceTxt );
+	$sourceTxt = preg_replace_callback( '/(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)/i', "InsertLookupLinkIP", $sourceTxt );
+}
+
+/*
+*	AddContextLinks
+*/
+function AddWindowLoadFocus($szFieldID)
+{
+	global $content;
+
+	// Add Javascript to Focus a specific element
+	$content['EXTRA_JAVASCRIPT'] .= "<script>window.onload = function(){ document.getElementById('" . $szFieldID . "').focus(); };</script>"; 
+}
+
+
 /*
 *	Helper to create a Lookup Link!
 */
-function InsertLookupLink( $szIP, $szDomain, $prepend, $append )
+function InsertLookupLinkIP( $matches ) // $szIP, $szDomain, $prepend, $append )
 {
 	global $content, $uID;
 
+	$szIP = $matches[1] . "." . $matches[2] . "." . $matches[3] . "." . $matches[4]; 
+	$prepend = "";
+	$append = "";
+
 	// Create string
 	$szReturn = $prepend;
 
@@ -1503,37 +1577,47 @@ function InsertLookupLink( $szIP, $szDomain, $prepend, $append )
 	else
 		$includeLinkUID = "";
 	
-	// check if it is an IP or domain
-	if ( strlen($szIP) > 0 )
-	{
-/*		// Split IP into array
-		$IPArray = explode(".", $szIP);
-		if ( 
-				(intval($IPArray[0]) == 10	) ||
-				(intval($IPArray[0]) == 127 ) ||
-				(intval($IPArray[0]) == 172 && intval($IPArray[1]) >= 16 && intval($IPArray[1]) <= 31) || 
-				(intval($IPArray[0]) == 192	&& intval($IPArray[1]) == 168) ||
-				(intval($IPArray[0]) == 255	)
-			)
+	if ( IsInternalIP($szIP) )
+		// Do not create a LINK in this case!
+		$szReturn .= '<b>' . $szIP . '</b>';
+	else
+		// Normal LINK!
+		$szReturn .= '<a href="http://kb.monitorware.com/kbsearch.php?sa=whois&oid=ip&origin=phplogcon&q=' . $szIP . '" target="_top" class="contextlink">' . $szIP . '</a>';
+
+	// Add InfoSearch Link
+	$szReturn .= '<a href="asktheoracle.php?type=ip&query=' . $szIP . $includeLinkUID . '" target="_top"><img src="' . $content['MENU_HELP_BLUE'] . '" width="16" height="16" title="' . $content['LN_GEN_MOREINFORMATION'] . '"></a>';
+
+	// Append the append string now
+	$szReturn .= $append;
+
+	// return result
+	return $szReturn;
+}
+
+/*
+*	Helper to create a Lookup Link!
 */
-		if ( IsInternalIP($szIP) )
-			// Do not create a LINK in this case!
-			$szReturn .= '<b>' . $szIP . '</b>';
-		else
-			// Normal LINK!
-			$szReturn .= '<a href="http://kb.monitorware.com/kbsearch.php?sa=whois&oid=ip&origin=phplogcon&q=' . $szIP . '" target="_top" class="contextlink">' . $szIP . '</a>';
+function InsertLookupLinkDomain( $matches ) // $szIP, $szDomain, $prepend, $append )
+{
+	global $content, $uID;
 
-		// Add InfoSearch Link
-		$szReturn .= '<a href="asktheoracle.php?type=ip&query=' . $szIP . $includeLinkUID . '" target="_top"><img src="' . $content['MENU_HELP_BLUE'] . '" width="16" height="16" title="' . $content['LN_GEN_MOREINFORMATION'] . '"></a>';
-	}
-	else if ( strlen($szDomain) > 0 ) 
-	{
-		$szReturn .= '<a href="http://kb.monitorware.com/kbsearch.php?sa=whois&oid=name&origin=phplogcon&q=' . $szDomain . '" target="_top" class="contextlink">' . $szDomain . '</a>';
+	$szDomain = $matches[1] . "." . $matches[2]; 
+	$prepend = "."; 
+	$append = $matches[3]; 
 
-		// Add InfoSearch Link
-		$szReturn .= '<a href="asktheoracle.php?type=domain&query=' . $szDomain . $includeLinkUID . '" target="_top"><img src="' . $content['MENU_HELP_BLUE'] . '" width="16" height="16" title="' . $content['LN_GEN_MOREINFORMATION'] . '"></a>';
+	// Create string
+	$szReturn = $prepend;
 
-	}
+	// Set IUD property if available
+	if ( isset($uID) )
+		$includeLinkUID = "&uid=" . $uID;
+	else
+		$includeLinkUID = "";
+	
+	$szReturn .= '<a href="http://kb.monitorware.com/kbsearch.php?sa=whois&oid=name&origin=phplogcon&q=' . $szDomain . '" target="_top" class="contextlink">' . $szDomain . '</a>';
+
+	// Add InfoSearch Link
+	$szReturn .= '<a href="asktheoracle.php?type=domain&query=' . $szDomain . $includeLinkUID . '" target="_top"><img src="' . $content['MENU_HELP_BLUE'] . '" width="16" height="16" title="' . $content['LN_GEN_MOREINFORMATION'] . '"></a>';
 
 	// Append the append string now
 	$szReturn .= $append;
@@ -1568,18 +1652,26 @@ function IsInternalIP($szIPAddress)
 /*
 *	Reserve Resolve IP Address!
 */
-function ReverseResolveIP( $szIP, $prepend, $append )
+function ReverseResolveIP( $matches ) // $szIP, $prepend, $append )
 {
 	global $gl_starttime, $content; 
 
+	// Callback functions seem to always call sessionstart
+	@session_start();
+
+	// Set Properties here now!
+	$szIP = $matches[2] . "." . $matches[3] . "." . $matches[4] . "." . $matches[5]; 
+	$prepend = $matches[1] . $szIP . '<font class=\"highlighted\"> {'; 
+	$append = '} </font>'; 
+
 	// Substract 5 seconds we need to finish processing!
 	$scriptruntime = intval(microtime_float() - $gl_starttime);
 	if ( $content['MaxExecutionTime'] > 0 && $scriptruntime > ($content['MaxExecutionTime']-5) )
-		return "";
+		return $matches[0];
 
 	// Abort if these IP's are postet
 	if ( strpos($szIP, "0.0.0.0") !== false | strpos($szIP, "127.") !== false | strpos($szIP, "255.255.255.255") !== false ) 
-		return "";
+		return $matches[0];
 	else
 	{
 		// Resolve name if needed
@@ -1588,13 +1680,16 @@ function ReverseResolveIP( $szIP, $prepend, $append )
 		
 		// Abort if IP and RESOLVED name are the same ^^!
 		if ( $_SESSION['dns_cache'][$szIP] == $szIP || strlen($_SESSION['dns_cache'][$szIP]) <= 0 )
-			return;
+			return $matches[0];
 
 		// Create string
 		$szReturn  = $prepend;
 		$szReturn .= $_SESSION['dns_cache'][$szIP];
 		$szReturn .= $append;
 
+//		echo $szReturn; 
+//		exit; 
+
 		// return result
 		return $szReturn;
 	}
@@ -1622,6 +1717,7 @@ function StartPHPSession()
 		// This will start the session
 		@session_start();
 
+
 		if ( !isset($_SESSION['SESSION_STARTED']) )
 			$_SESSION['SESSION_STARTED'] = "true";
 	}
@@ -1704,6 +1800,8 @@ function SaveGeneralSettingsIntoDB($bForceStripSlahes = false)
 	// Extra Fields
 	WriteConfigValue( "DefaultViewsID", true, null, null,$bForceStripSlahes );
 	WriteConfigValue( "DefaultSourceID", true, null, null,$bForceStripSlahes );
+	WriteConfigValue( "DefaultFont", true, null, null,$bForceStripSlahes );
+	WriteConfigValue( "DefaultFontSize", true, null, null,$bForceStripSlahes );
 	
 	// GLOBAL ONLY
 	WriteConfigValue( "DebugUserLogin", true, null, null,$bForceStripSlahes );
@@ -1711,6 +1809,7 @@ function SaveGeneralSettingsIntoDB($bForceStripSlahes = false)
 	WriteConfigValue( "MiscMaxExecutionTime", true, null, null,$bForceStripSlahes );
 	WriteConfigValue( "UseProxyServerForRemoteQueries", true, null, null,$bForceStripSlahes );
 	WriteConfigValue( "HeaderDefaultEncoding", true, null, null,$bForceStripSlahes );
+	WriteConfigValue( "DisableAdminUsers", true, null, null,$bForceStripSlahes );
 
 	// Custom HTML Code 
 	WriteConfigValue( "InjectHtmlHeader", true, null, null,$bForceStripSlahes );
@@ -1752,6 +1851,9 @@ function SaveUserGeneralSettingsIntoDB()
 	// Extra Fields
 	WriteConfigValue( "DefaultViewsID", false, $content['SESSION_USERID'] );
 	WriteConfigValue( "DefaultSourceID", false, $content['SESSION_USERID'] );
+	WriteConfigValue( "DefaultFont", false, $content['SESSION_USERID'] );
+	WriteConfigValue( "DefaultFontSize", false, $content['SESSION_USERID'] );
+	
 }
 
 
@@ -2024,5 +2126,108 @@ function strip_dangerous_html_tags( $text )
 	return $text; 
 }
 
+// Creates a list of supported available fonts!
+function InitFontList()
+{
+	global $content; 
+
+	$content["fonts"]["Arial"]["Name"]			= "Arial"; 
+	$content["fonts"]["Century"]["Name"]		= "Century"; 
+	$content["fonts"]["Courier"]["Name"]		= "Courier"; 
+	$content["fonts"]["Courier New"]["Name"]	= "Courier New"; 
+	$content["fonts"]["Georgia"]["Name"]		= "Georgia"; 
+	$content["fonts"]["Impact"]["Name"]			= "Impact"; 
+	$content["fonts"]["Lucida Console"]["Name"]	= "Lucida Console"; 
+	$content["fonts"]["serif"]["Name"]			= "serif"; 
+	$content["fonts"]["sans-serif"]["Name"]		= "sans-serif"; 
+	$content["fonts"]["Tahoma"]["Name"]			= "Tahoma"; 
+	$content["fonts"]["Times"]["Name"]			= "Times"; 	
+	$content["fonts"]["Times New Roman"]["Name"]= "Times New Roman"; 
+	$content["fonts"]["Trebuchet MS"]["Name"]	= "Trebuchet MS"; 
+	$content["fonts"]["Verdana"]["Name"]		= "Verdana"; 
+}
+
+// Creates a list of supported available fonts!
+function InitFontSizeList()
+{
+	global $content; 
+
+	$content["fontsizes"]["50"]["Name"]			= "50%"; 
+	$content["fontsizes"]["60"]["Name"]			= "60%"; 
+	$content["fontsizes"]["70"]["Name"]			= "70%"; 
+	$content["fontsizes"]["80"]["Name"]			= "80%"; 
+	$content["fontsizes"]["90"]["Name"]			= "90%"; 
+	$content["fontsizes"]["100"]["Name"]		= "100%"; 
+	$content["fontsizes"]["110"]["Name"]		= "110%"; 
+	$content["fontsizes"]["120"]["Name"]		= "120%"; 
+	$content["fontsizes"]["130"]["Name"]		= "130%"; 
+	$content["fontsizes"]["140"]["Name"]		= "140%"; 
+	$content["fontsizes"]["150"]["Name"]		= "150%"; 
+	$content["fontsizes"]["160"]["Name"]		= "160%"; 
+	$content["fontsizes"]["170"]["Name"]		= "170%"; 
+	$content["fontsizes"]["180"]["Name"]		= "180%"; 
+	$content["fontsizes"]["190"]["Name"]		= "190%"; 
+	$content["fontsizes"]["200"]["Name"]		= "200%"; 
+}
 // --- 
+
+/* 
+Helper function to set dynamic css 
+*/
+function InitFontSettings()
+{
+	global $content; 
+
+	// --- Set dynamic stylesheet options like Font Type and Sizes
+	if ( isset($_SERVER['HTTP_USER_AGENT']) && strpos($_SERVER['HTTP_USER_AGENT'], "Windows") !== false ) // Use other default on Windows
+		$userdefaultfont = GetConfigSetting("DefaultFont", "Trebuchet MS", CFGLEVEL_USER);  
+	else
+		$userdefaultfont = GetConfigSetting("DefaultFont", "Arial", CFGLEVEL_USER);  
+	$userdefaultfontsize = GetConfigSetting("DefaultFontSize", "100", CFGLEVEL_USER);  
+
+	/* Set Defaults if not set already! */
+	if ( strlen($userdefaultfont) <= 0 ) 
+		$userdefaultfont = "Arial"; 
+	if ( strlen($userdefaultfontsize) <= 0 ) 
+		$userdefaultfontsize = "100"; 
+	
+	$content['DYN_STYLESHEET'] = '<style>
+		body, td, select, input, .ui-widget, .ui-widget-content {
+			font-family: ' . $userdefaultfont . ', Verdana, Arial, Helvetica, sans-serif;
+			font-size: ' . ($userdefaultfontsize/10)*1.10  . 'px; 
+		}
+		a, .linksize {
+			font-size: ' . ($userdefaultfontsize/10)*1.1 . 'px; 
+		}
+		.ui-menu, .title {
+			font-size: ' . ($userdefaultfontsize/10)*1.3 . 'px; 
+		}
+		.ui-button, .ErrorMsg, .topmenu2 {
+			font-size: ' . ($userdefaultfontsize/10)*1.2 . 'px; 
+		}
+	</style>'; 
+	// --- 
+}
+
+function ReplaceDollarChar($myValue)
+{
+	if ( is_array($myValue) )
+	{	// Array value
+		$retArray = array(); 
+		foreach( $myValue as $mykey => $myString )
+		{
+			// Add slashes before $ characters
+			$retArray[$mykey] = addcslashes ( $retArray[$mykey], "$" ); 
+		}
+
+		// Return fixed array!
+		return $retArray; 
+	}
+	else
+	{
+		// Add slashes before $ characters
+		return addcslashes( $myValue, "$" );
+	}
+}
+
 ?>
\ No newline at end of file
