@@ -54,7 +54,7 @@ InitFilterHelpers();	// Helpers for frontend filtering!
 // ---
 
 // --- Define Extra Stylesheet!
-$content['EXTRA_STYLESHEET']  = '<link rel="stylesheet" href="css/highlight.css" type="text/css">' . "\r\n";
+$content['EXTRA_STYLESHEET'] = '<link rel="stylesheet" href="css/highlight.css" type="text/css">' . "\r\n";
 // --- 
 
 // --- CONTENT Vars
@@ -316,7 +316,7 @@ if ( isset($content['Sources'][$currentSourceID]) )
 				$content['main_recordcount_found'] = false;
 			
 			$content['main_currentpagenumber'] = $stream->GetCurrentPageNumber();
-			if ( $content['main_currentpagenumber'] >= 0 )
+			if ( $content['main_currentpagenumber'] > 0 )
 				$content['main_currentpagenumber_found'] = true;
 			else
 				$content['main_currentpagenumber_found'] = false;
@@ -533,15 +533,18 @@ if ( isset($content['Sources'][$currentSourceID]) )
 									$content['syslogmessages'][$counter]['values'][$mycolkey]['fieldvalue'] = HighLightString( $content['highlightwords'], $content['syslogmessages'][$counter]['values'][$mycolkey]['fieldvalue'] );
 
 								// --- HOOK here to add context links!
+								$content['syslogmessages'][$counter]['values'][$mycolkey]['fieldvaluenolink'] = $content['syslogmessages'][$counter]['values'][$mycolkey]['fieldvalue'];
 								AddContextLinks($content['syslogmessages'][$counter]['values'][$mycolkey]['fieldvalue']);
+								AddContextHighlights($content['syslogmessages'][$counter]['values'][$mycolkey]['fieldvaluenolink']);
 								// --- 
 
 								if ( GetConfigSetting("ViewEnableDetailPopups", 0, CFGLEVEL_USER) )
 								{
 									$content['syslogmessages'][$counter]['values'][$mycolkey]['popupcaption'] = GetAndReplaceLangStr( $content['LN_GRID_POPUPDETAILS'], $logArray[SYSLOG_UID]);
+									$content['syslogmessages'][$counter]['values'][$mycolkey]['popupcaptionjs'] = EscapeQuotesFromString($content['syslogmessages'][$counter]['values'][$mycolkey]['popupcaption']);
 									$content['syslogmessages'][$counter]['values'][$mycolkey]['hasdetails'] = "true";
 									$content['syslogmessages'][$counter]['values'][$mycolkey]['detailimagealign'] = "left"; // Other alignment needed!
-
+/* DetailPopup Code not needed anymore 
 									foreach($content['syslogmessages'][$counter]['values'] as $mykey => $myfield)
 									{
 										// Set Caption!
@@ -575,6 +578,7 @@ if ( isset($content['Sources'][$currentSourceID]) )
 										else // Just set field value
 											$content['syslogmessages'][$counter]['values'][$mycolkey]['messagesdetails'][$myIndex]['detailfieldvalue'] = isset($myfield['rawfieldvalue']) ? GetStringWithHTMLCodes($myfield['rawfieldvalue']) : GetStringWithHTMLCodes($myfield['fieldvalue']);
 									}
+*/
 								}
 
 								if ( strlen($content['searchstr']) > 0 )
@@ -922,8 +926,13 @@ function AddOnClickMenu(&$fieldGridItem, $fieldType, $FieldID)
 {
 	global $content, $fields, $myStrCharLimit; 
 
-	// Set OnClick Menu for SYSLOG_SYSLOGTAG
-	$fieldGridItem['hasbuttons'] = true;
+	if ( strlen($fieldGridItem['fieldvalue']) <= 0 ) {
+		$fieldGridItem['hasbuttons'] = false;
+		return; 
+	}
+	else
+		// Enable OnClick Menu 
+		$fieldGridItem['hasbuttons'] = true;
 	
 	// Set Field Caption
 	if ( isset($content['fields'][$FieldID]['FieldCaption']) && strlen( $content['fields'][$FieldID]['FieldCaption']) > 0 ) 
