@@ -29,23 +29,23 @@ global $content;
 
 // Global Stuff
 $content['LN_MAINTITLE'] = "Hauptseite LogAnalyzer";
-$content['LN_MAIN_SELECTSTYLE'] = "Style ausw&auml;hlen";
-$content['LN_GEN_LANGUAGE'] = "Sprache ausw&auml;hlen";
-$content['LN_GEN_SELECTSOURCE'] = "Quelle ausw&auml;len";
-$content['LN_GEN_MOREPAGES'] = "Mehr als eine Seite verf&uuml;gbar";
+$content['LN_MAIN_SELECTSTYLE'] = "Style auswählen";
+$content['LN_GEN_LANGUAGE'] = "Sprache auswählen";
+$content['LN_GEN_SELECTSOURCE'] = "Quelle auswälen";
+$content['LN_GEN_MOREPAGES'] = "Mehr als eine Seite verfügbar";
 $content['LN_GEN_FIRSTPAGE'] = "Erste Seite";
 $content['LN_GEN_LASTPAGE'] = "Letzte Seite";
-$content['LN_GEN_NEXTPAGE'] = "N&auml;chste Seite";
+$content['LN_GEN_NEXTPAGE'] = "Nächste Seite";
 $content['LN_GEN_PREVIOUSPAGE'] = "Vorherige Seite";
-$content['LN_GEN_RECORDCOUNT'] = "Alle gefundenen Eintr&auml;ge";
-$content['LN_GEN_PAGERSIZE'] = "Eintr&auml;ge pro Seite";
+$content['LN_GEN_RECORDCOUNT'] = "Alle gefundenen Einträge";
+$content['LN_GEN_PAGERSIZE'] = "Einträge pro Seite";
 $content['LN_GEN_PAGE'] = "Seite";
 $content['LN_GEN_PREDEFINEDSEARCHES'] = "Vordefinierte Suchkriterien";
 $content['LN_GEN_SOURCE_DISK'] = "Datei";
 $content['LN_GEN_SOURCE_DB'] = "Datenbank";
 $content['LN_GEN_RECORDSPERPAGE'] = "Zeilen pro Seite";
 $content['LN_GEN_PRECONFIGURED'] = "Vorkonfiguriert";
-$content['LN_GEN_AVAILABLESEARCHES'] = "Verf&uuml;gbare Suchabfragen";
+$content['LN_GEN_AVAILABLESEARCHES'] = "Verfügbare Suchabfragen";
 $content['LN_GEN_DB_MYSQL'] = "MySQL Server";
 $content['LN_GEN_DB_MSSQL'] = "Microsoft SQL Server";
 $content['LN_GEN_DB_ODBC'] = "ODBC Datenbank Quelle";
@@ -55,48 +55,48 @@ $content['LN_GEN_DB_DB2'] = "	IBM DB2";
 $content['LN_GEN_DB_FIREBIRD'] = "Firebird/Interbase 6";
 $content['LN_GEN_DB_INFORMIX'] = "IBM Informix Dynamic Server";
 $content['LN_GEN_DB_SQLITE'] = "SQLite 2";
-$content['LN_GEN_SELECTVIEW'] = "Anzeige ausw&auml;hlen";
-$content['LN_GEN_CRITERROR_UNKNOWNTYPE'] = "Der Quell-Typ '%1' wird aktuell von LogAnalyzer nicht unterst&uum;tzt. Dies ist ein kritischer Fehler, bitte passen Sie Ihre Konfiguration an.";
-$content['LN_GEN_ERRORRETURNPREV'] = "Bitte klicken Sie hier, um auf die vorhergehende Seite zur&uuml;ckzukehren.";
+$content['LN_GEN_SELECTVIEW'] = "Anzeige auswählen";
+$content['LN_GEN_CRITERROR_UNKNOWNTYPE'] = "Der Quell-Typ '%1' wird aktuell von LogAnalyzer nicht unterstützt. Dies ist ein kritischer Fehler, bitte passen Sie Ihre Konfiguration an.";
+$content['LN_GEN_ERRORRETURNPREV'] = "Bitte klicken Sie hier, um auf die vorhergehende Seite zurückzukehren.";
 $content['LN_GEN_ERRORDETAILS'] = "Fehler Details:";
-$content['LN_SOURCES_ERROR_WITHINSOURCE'] = "Die &Uuml;berpr&uuml;fung der Quelle '%1' endete mit dem Fehler: '%2'";
+$content['LN_SOURCES_ERROR_WITHINSOURCE'] = "Die überprüfung der Quelle '%1' endete mit dem Fehler: '%2'";
 $content['LN_SOURCES_ERROR_EXTRAMSG'] = "Extra Fehler Details:<br>%1";
-$content['LN_ERROR_NORECORDS'] = "Es wurden keine syslog-Eintr&auml;ge gefunden.";
+$content['LN_ERROR_NORECORDS'] = "Es wurden keine syslog-Einträge gefunden.";
 $content['LN_ERROR_FILE_NOT_FOUND'] = "Die Syslog Datei konnte nicht gefunden werden";
 $content['LN_ERROR_FILE_NOT_READABLE'] = "Die Syslog Datei ist nicht lesbar, lesender Zugriff ist evtl. nicht gestattet";
 $content['LN_ERROR_UNKNOWN'] = "Ein unbekannter oder unerwarteter Fehler ist aufgetreten. (Fehler Code '%1')";
 $content['LN_ERROR_FILE_EOF'] = "Ende der Datei erreicht";
 $content['LN_ERROR_FILE_BOF'] = "Anfang der Datei erreicht";
-$content['LN_ERROR_FILE_CANT_CLOSE'] = "Das Schliessen der Datei ist nicht m&ouml;glich";
+$content['LN_ERROR_FILE_CANT_CLOSE'] = "Das Schliessen der Datei ist nicht möglich";
 $content['LN_ERROR_UNDEFINED'] = "Unerwarteter Fehler";
 $content['LN_ERROR_EOS'] = "Ende des Datenstroms erreicht";
-$content['LN_ERROR_FILTER_NOT_MATCH'] = "Der Filter ergab keine &Uuml;bereinstimmung im Ergbenis";
+$content['LN_ERROR_FILTER_NOT_MATCH'] = "Der Filter ergab keine übereinstimmung im Ergbenis";
 $content['LN_ERROR_DB_CONNECTFAILED'] = "Die Verbindung zum Datenbank Server ist fehlgeschlagen";
 $content['LN_ERROR_DB_CANNOTSELECTDB'] = "Die in der Konfiguration angegeben Datenbank konnte nicht gefunden werden";
-$content['LN_ERROR_DB_QUERYFAILED'] = "Die Datenbank-Abfrage konnte nicht ausgef&uuml;hrt werden";
+$content['LN_ERROR_DB_QUERYFAILED'] = "Die Datenbank-Abfrage konnte nicht ausgeführt werden";
 $content['LN_ERROR_DB_NOPROPERTIES'] = "Keine Einstellungen zur Datenbank gefunden";
-$content['LN_ERROR_DB_INVALIDDBMAPPING'] = "Ung&uuml;ltige Datenfeld Zuordnung";
-$content['LN_ERROR_DB_INVALIDDBDRIVER'] = "Ung&uuml;ltiger Datenbank Treiber ausgew&auml;hlt";
+$content['LN_ERROR_DB_INVALIDDBMAPPING'] = "Ungültige Datenfeld Zuordnung";
+$content['LN_ERROR_DB_INVALIDDBDRIVER'] = "Ungültiger Datenbank Treiber ausgewählt";
 $content['LN_ERROR_DB_TABLENOTFOUND'] = "Die angegebene Tabelle konnte nicht gefunden werden, evtl. ist der Eintrag falsch geschrieben oder Gross- und Kleinschreibung wurden nicht beachtet.";
 $content['LN_ERROR_DB_DBFIELDNOTFOUND'] = "Die Datenbankfeldzuordnung ist fehlerhaft, es konnte mindestens ein Feld nicht gefunden werden.";
-$content['LN_GEN_SELECTEXPORT'] = "&gt; Exportformat ausw&auml;hlen &lt;";
+$content['LN_GEN_SELECTEXPORT'] = "&gt; Exportformat auswählen &lt;";
 $content['LN_GEN_EXPORT_CVS'] = "CSV (Komma unterteilt)";
 $content['LN_GEN_EXPORT_XML'] = "XML";
 $content['LN_GEN_EXPORT_PDF'] = "PDF";
 $content['LN_GEN_ERROR_EXPORING'] = "Fehler beim exportieren der Daten";
-$content['LN_GEN_ERROR_INVALIDEXPORTTYPE'] = "Ung&uuml;ltiges Export Format ausgew&auml;htl, oder andere Parameter sind ung&uuml;ltig.";
+$content['LN_GEN_ERROR_INVALIDEXPORTTYPE'] = "Ungültiges Export Format ausgewähtl, oder andere Parameter sind ungültig.";
 $content['LN_GEN_ERROR_SOURCENOTFOUND'] = "Die Quelle mit der ID '%1' konnte nicht gefunden werden.";
 $content['LN_GEN_MOREINFORMATION'] = "Mehr Informationen";
-$content['LN_FOOTER_PAGERENDERED'] = "Siete gerenderet in";
+$content['LN_FOOTER_PAGERENDERED'] = "Seite berechnet in";
 $content['LN_FOOTER_DBQUERIES'] = "DB Abfragen";
-$content['LN_FOOTER_GZIPENABLED'] = "GZIP erm&ouml;glichen";
+$content['LN_FOOTER_GZIPENABLED'] = "GZIP ermöglichen";
 $content['LN_FOOTER_SCRIPTTIMEOUT'] = "Max. Skript Laufzeit";
 $content['LN_FOOTER_SECONDS'] = "Sekunden";
 $content['LN_WARNING_LOGSTREAMTITLE'] = "Log-Datenstrom Warnung";
-$content['LN_WARNING_LOGSTREAMDISK_TIMEOUT'] = "Beim lesen des Log-Datenstroms, hat das PHP-Skript die max. Laufzeit erreicht und wurde abgebrochen.<br><br> Falls Sie dennoch die Ausf&uuml;hrung erm&ouml;glichen wollen, bitte erh&ouml;hen Sie die max. LogAnalyzer Skript Laufzeit in Ihrer config.php. Falls das Benutzersystem installiert ist, k&ouml;nnen Sie dies im Bereich Administration einstellen.";
+$content['LN_WARNING_LOGSTREAMDISK_TIMEOUT'] = "Beim lesen des Log-Datenstroms, hat das PHP-Skript die max. Laufzeit erreicht und wurde abgebrochen.<br><br> Falls Sie dennoch die Ausführung ermöglichen wollen, bitte erhöhen Sie die max. LogAnalyzer Skript Laufzeit in Ihrer config.php. Falls das Benutzersystem installiert ist, können Sie dies im Bereich Administration einstellen.";
 $content['LN_WARNING_DBUPGRADE'] = "Datenbank Upgrade erforderlich";
-$content['LN_WARNING_DBUPGRADE_TEXT'] = "Die aktuell installierte Datenbankversion ist '%1'.<br>Ein Update auf Version '%2' ist verf&uuml;gbar.";
-$content['LN_ERROR_REDIRECTABORTED'] = 'Automatiche R&uuml;ckkehr zur Seite <a href="%1">page</a> wurde abgebrochen, da ein interner Fehler aufgetrete ist. Bitte beachten Sie die weiteren Informationen zu diesem Fehler &uuml;ber dieser Meldung und/oder nehmen Sie Kontakt zum Support-Forum auf, falls Sie Hilfe ben&ouml;tigen.';
+$content['LN_WARNING_DBUPGRADE_TEXT'] = "Die aktuell installierte Datenbankversion ist '%1'.<br>Ein Update auf Version '%2' ist verfügbar.";
+$content['LN_ERROR_REDIRECTABORTED'] = 'Automatiche Rückkehr zur Seite <a href="%1">page</a> wurde abgebrochen, da ein interner Fehler aufgetrete ist. Bitte beachten Sie die weiteren Informationen zu diesem Fehler über dieser Meldung und/oder nehmen Sie Kontakt zum Support-Forum auf, falls Sie Hilfe benötigen.';
 $content['LN_DEBUGLEVEL'] = "Debug Level";
 $content['LN_DEBUGMESSAGE'] = "Debug Meldung";
 $content['LN_GEN_REPORT_OUTPUT_HTML'] = "HTML Format";
@@ -110,7 +110,7 @@ $content['LN_MENU_HELP'] = "Hilfe";
 $content['LN_MENU_DOC'] = "Dokumentation";
 $content['LN_MENU_FORUM'] = "Support Forum";
 $content['LN_MENU_WIKI'] = "LogAnalyzer Wiki";
-$content['LN_MENU_PROSERVICES'] = "Professionelle Unterst&uuml;tzung";
+$content['LN_MENU_PROSERVICES'] = "Professionelle Unterstützung";
 $content['LN_MENU_SEARCHINKB'] = "Suche in der Wissensdatenbank";
 $content['LN_MENU_LOGIN'] = "Anmeldung";
 $content['LN_MENU_ADMINCENTER'] = "Administration";
@@ -119,36 +119,35 @@ $content['LN_MENU_LOGGEDINAS'] = "Angemeldet als ";
 $content['LN_MENU_MAXVIEW'] = "Anzeige maximieren";
 $content['LN_MENU_NORMALVIEW'] = "Standard Anzeige";
 $content['LN_MENU_STATISTICS'] = "Statistiken";
-$content['LN_MENU_CLICKTOEXPANDMENU'] = "Klicken Sie das Icon um das Men&uuml; anzuzeigen";
-
+$content['LN_MENU_CLICKTOEXPANDMENU'] = "Klicken Sie das Icon um das Menü anzuzeigen";
 
 // Index Site
 $content['LN_ERROR_INSTALLFILEREMINDER'] = "Warnung! Sie haben das Installationsskript 'install.php' noch nicht aus dem LogAnalyzer Hauptordner entfernt!";
 $content['LN_TOP_NUM'] = "No.";
 $content['LN_TOP_UID'] = "uID";
-$content['LN_GRID_POPUPDETAILS'] = "Details f&uulm;r die Syslog-Meldung mit der ID '%1'";
+$content['LN_GRID_POPUPDETAILS'] = "Details für die Syslog-Meldung mit der ID '%1'";
 
-$content['LN_SEARCH_USETHISBLA'] = "Bitte ber&uuml;cksichtigen Sie bei Ihrer Suche folgende Kriterien";
+$content['LN_SEARCH_USETHISBLA'] = "Bitte berücksichtigen Sie bei Ihrer Suche folgende Kriterien";
 $content['LN_SEARCH_FILTER'] = "Suche (Filter):";
 $content['LN_SEARCH_ADVANCED'] = "Erweiterte Suche";
 $content['LN_SEARCH'] = "Suche";
-$content['LN_SEARCH_RESET'] = "Suche zur&uuml;cksetzen";
+$content['LN_SEARCH_RESET'] = "Suche zurücksetzen";
 $content['LN_SEARCH_PERFORMADVANCED'] = "Erweiterte Suche starten";
-$content['LN_VIEW_MESSAGECENTERED'] = "Zur&uuml;ck zur ungefilterten Ansicht, mit dieser Meldung als erster";
+$content['LN_VIEW_MESSAGECENTERED'] = "Zurück zur ungefilterten Ansicht, mit dieser Meldung als erster";
 $content['LN_VIEW_RELATEDMSG'] = "Anzeige vorheriger Syslog Meldungen ";
 $content['LN_VIEW_FILTERFOR'] = "Filtere Meldungen nach ";
 $content['LN_VIEW_SEARCHFOR'] = "Suche online nach ";
 $content['LN_VIEW_SEARCHFORGOOGLE'] = "Durchsuche Google nach ";
 $content['LN_GEN_MESSAGEDETAILS'] = "Meldungsdetails";
-$content['LN_VIEW_ADDTOFILTER'] = "F&uuml; '%1' zur Filterliste hinzu";
+$content['LN_VIEW_ADDTOFILTER'] = "Füge '%1' zur Filterliste hinzu";
 $content['LN_VIEW_EXCLUDEFILTER'] = "Entferne '%1' von der Filterliste";
 $content['LN_VIEW_FILTERFORONLY'] = "Filtere nur nach '%1'";
 $content['LN_VIEW_SHOWALLBUT'] = "Anzeige aller Meldungen, ausgenommen '%1'";
-$content['LN_VIEW_VISITLINK'] = "&Ouml;ffne Link '%1' in neuem Fenster";
+$content['LN_VIEW_VISITLINK'] = "Öffne Link '%1' in neuem Fenster";
 
 $content['LN_HIGHLIGHT'] = "Hervorhebung >>";
 $content['LN_HIGHLIGHT_OFF'] = "Hervorhebung <<";
-$content['LN_HIGHLIGHT_WORDS'] = "Hervorgehobene W&ouml;rter durch ein Komma voneinander trennen";
+$content['LN_HIGHLIGHT_WORDS'] = "Hervorgehobene Wörter durch ein Komma voneinander trennen";
 
 $content['LN_AUTORELOAD'] = "Auto. neu laden";
 $content['LN_AUTORELOAD_DISABLED'] = "Auto. neu laden deaktiviert";
@@ -158,7 +157,7 @@ $content['LN_AUTORELOAD_MINUTES'] = "Minuten";
 
 // Filter Options
 $content['LN_FILTER_DATE'] = "Zeitliche Abgrenzung";
-$content['LN_FILTER_DATEMODE'] = "Zeitraum ausw&auml;hlen";
+$content['LN_FILTER_DATEMODE'] = "Zeitraum auswählen";
 $content['LN_DATEMODE_ALL'] = "Kompletter Zeitraum";
 $content['LN_DATEMODE_RANGE'] = "Zeitspanne";
 $content['LN_DATEMODE_LASTX'] = "Seit heute, x Uhr";
@@ -167,7 +166,7 @@ $content['LN_FILTER_DATETO'] = "Zeitraum bis x";
 $content['LN_FILTER_TIMEFROM'] = "Time range from";
 $content['LN_FILTER_TIMETO'] = "Time range to";
 $content['LN_FILTER_DATELASTX'] = "Zeit seit";
-$content['LN_FILTER_ADD2SEARCH'] = "Zur Suche hinzuf&uuml;gen";
+$content['LN_FILTER_ADD2SEARCH'] = "Zur Suche hinzufügen";
 $content['LN_DATE_LASTX_HOUR'] = "in der letzten Stunde";
 $content['LN_DATE_LASTX_12HOURS'] = "in den letzten 12 Stunden";
 $content['LN_DATE_LASTX_24HOURS'] = "in den letzten 24 Stunden";
@@ -185,10 +184,10 @@ $content['LN_FILTER_MESSAGETYPE'] = "Meldungs Typ";
 $content['LN_CFG_DBSERVER'] = "Datenbank Host";
 $content['LN_CFG_DBPORT'] = "Datenbank Port";
 $content['LN_CFG_DBNAME'] = "Datenbank Name";
-$content['LN_CFG_DBPREF'] = "Tabellen Pr&auml;fix";
+$content['LN_CFG_DBPREF'] = "Tabellen Präfix";
 $content['LN_CFG_DBUSER'] = "Datenbank Benutzer";
 $content['LN_CFG_DBPASSWORD'] = "Datenbank Passwort";
-$content['LN_CFG_PARAMMISSING'] = "Die folgenden Parameter k&ouml;nnen nicht gefunden werden: ";
+$content['LN_CFG_PARAMMISSING'] = "Die folgenden Parameter können nicht gefunden werden: ";
 $content['LN_CFG_SOURCETYPE'] = "Quell-Typ";
 $content['LN_CFG_DISKTYPEOPTIONS'] = "Disk-Typ Optionen";
 $content['LN_CFG_LOGLINETYPE'] = "Logzeilentyp";
@@ -199,20 +198,20 @@ $content['LN_CFG_DBSTORAGEENGINE'] = "Datenbank Typ";
 $content['LN_CFG_DBTABLENAME'] = "Datenbank Tabellenname";
 $content['LN_CFG_NAMEOFTHESOURCE'] = "Name der Quelle";
 $content['LN_CFG_FIRSTSYSLOGSOURCE'] = "Erste Syslog Quelle";
-$content['LN_CFG_VIEW'] = "Anzeige ausw&auml;hlen";
+$content['LN_CFG_VIEW'] = "Anzeige auswählen";
 $content['LN_CFG_DBUSERLOGINREQUIRED'] = "Erfordert eine Benutzer-Anmeldung";
 $content['LN_CFG_MSGPARSERS'] = "Meldungs Parser (Komma getrent)";
 $content['LN_CFG_NORMALIZEMSG'] = "Standard Meldunganzeige mit Parser";
-$content['LN_CFG_SKIPUNPARSEABLE'] = "&Uuml;berspringe nicht lesbare Meldungen (Nur m&ouml;glich, wenn ein Parsen konfiguriert wurde!)";
+$content['LN_CFG_SKIPUNPARSEABLE'] = "überspringe nicht lesbare Meldungen (Nur möglich, wenn ein Parsen konfiguriert wurde!)";
 $content['LN_CFG_DBRECORDSPERQUERY'] = "Anzahl der Datenbankabfragen";
 
 // Details page
-$content['LN_DETAILS_FORSYSLOGMSG'] = "Details f&uuml;r Syslog-Nachrichten mit der ID";
-$content['LN_DETAILS_DETAILSFORMSG'] = "Details f&uuml;r Nachrichten-ID";
-$content['LN_DETAIL_BACKTOLIST'] = "Zur&uuml;ck zur Listenansicht";
+$content['LN_DETAILS_FORSYSLOGMSG'] = "Details für Syslog-Nachrichten mit der ID";
+$content['LN_DETAILS_DETAILSFORMSG'] = "Details für Nachrichten-ID";
+$content['LN_DETAIL_BACKTOLIST'] = "Zurück zur Listenansicht";
 
 // Login Site
-$content['LN_LOGIN_DESCRIPTION'] = "Bitte geben Sie Ihren Benutzernamen und Ihr dazugeh&ouml;riges Passwort ein, um sich bei LogAnalyzer anzumelden. ";
+$content['LN_LOGIN_DESCRIPTION'] = "Bitte geben Sie Ihren Benutzernamen und Ihr dazugehöriges Passwort ein, um sich bei LogAnalyzer anzumelden. ";
 $content['LN_LOGIN_TITLE'] = "Anmeldung";
 $content['LN_LOGIN_USERNAME'] = "Benutzername";
 $content['LN_LOGIN_PASSWORD'] = "Passwort";
@@ -298,9 +297,9 @@ $content['LN_STATS_COUNTBY'] = "Meldungsanzahl '%1'";
 $content['LN_STATS_GRAPH'] = "Grafik";
 $content['LN_STATS_TOPRECORDS'] = "Max. Anzahl: %1";
 $content['LN_STATS_GENERATEDAT'] = "Erstellumgsdatum: %1";
-$content['LN_GEN_ERROR_INVALIDFIELD'] = "Ung&uuml;tiger Feldname";
+$content['LN_GEN_ERROR_INVALIDFIELD'] = "Ungütiger Feldname";
 $content['LN_GEN_ERROR_MISSINGCHARTFIELD'] = "Fehlender Feldname";
-$content['LN_GEN_ERROR_INVALIDTYPE'] = "Ung&uuml;ltiger oder unbekannter Chart Typ";
+$content['LN_GEN_ERROR_INVALIDTYPE'] = "Ungültiger oder unbekannter Chart Typ";
 $content['LN_ERROR_CHARTS_NOTCONFIGURED'] = "Es wurden kein Chart konfiguriert.";
 $content['LN_CHART_TYPE'] = "Chart Typ";
 $content['LN_CHART_WIDTH'] = "Chart Breite";
@@ -310,23 +309,23 @@ $content['LN_CHART_SHOWPERCENT'] = "Prozentuale Anzeige";
 $content['LN_CHART_TYPE_CAKE'] = "Kuchen (Pie)";
 $content['LN_CHART_TYPE_BARS_VERTICAL'] = "Balken vertikal";
 $content['LN_CHART_TYPE_BARS_HORIZONTAL'] = "Balken horizontal";
-$content['LN_STATS_WARNINGDISPLAY'] = "Das Erstellen von Grafiken &uuml;ber eine grosse Anzahl von Datens&auml;tzen kann sehr Prozessortlastig sein.<br>Dies wird in nachfolgenden Versionen noch weiter optimiert werden.<br>Falls die Erstellung der Grafiken zu viel Prozessortzeit in Anspruch nehmen sollte, bitte brechen Sie die Erstellung einfach ab.";
+$content['LN_STATS_WARNINGDISPLAY'] = "Das Erstellen von Grafiken über eine grosse Anzahl von Datensätzen kann sehr Prozessortlastig sein.<br>Dies wird in nachfolgenden Versionen noch weiter optimiert werden.<br>Falls die Erstellung der Grafiken zu viel Prozessortzeit in Anspruch nehmen sollte, bitte brechen Sie die Erstellung einfach ab.";
 
 // asktheoracle site
 $content['LN_ORACLE_TITLE'] = "Fragen Sie das Orakel nach '%1'";
-$content['LN_ORACLE_HELP_FOR'] = "Das sind die Links welche das Orakel f&uuml;r Sie ermittelt hat";
-$content['LN_ORACLE_HELP_TEXT'] = "<br><h3>Sie haben das Orakel nach mehr Informationen &uuml;ber '%1' - '%2' gefragt.</h3>
-<p align=\"left\">Diese Seite erm&ouml;glicht es Ihnen eine Suche &uuml;ber verschiedene Log-Quellen zu starten. %3
-<br>Die Idee ist es, einfach nach Informationen &uuml;ber spezifizierte Angaben allerorts zu suchen, egal wo diese vorkommen.
+$content['LN_ORACLE_HELP_FOR'] = "Das sind die Links welche das Orakel für Sie ermittelt hat";
+$content['LN_ORACLE_HELP_TEXT'] = "<br><h3>Sie haben das Orakel nach mehr Informationen über '%1' - '%2' gefragt.</h3>
+<p align=\"left\">Diese Seite ermöglicht es Ihnen eine Suche über verschiedene Log-Quellen zu starten. %3
+<br>Die Idee ist es, einfach nach Informationen über spezifizierte Angaben allerorts zu suchen, egal wo diese vorkommen.
 </p>
 ";
-$content['LN_ORACLE_HELP_TEXT_EXTERNAL'] = "Es wird eine Suche &uuml;ber externe Datenquellen erm&ouml;glichti.";
-$content['LN_ORACLE_HELP_DETAIL'] = "Link &Uuml;bersicht f&uuml;r '%1' - '%2'";
+$content['LN_ORACLE_HELP_TEXT_EXTERNAL'] = "Es wird eine Suche über externe Datenquellen ermöglicht.";
+$content['LN_ORACLE_HELP_DETAIL'] = "Link übersicht für '%1' - '%2'";
 $content['LN_ORACLE_SEARCH'] = "Suche"; // in '%1' Field";
 $content['LN_ORACLE_SOURCENAME'] = "Quellen Name";
 $content['LN_ORACLE_FIELD'] = "Feld";
 $content['LN_ORACLE_ONLINESEARCH'] = "Online Suche";
-$content['LN_ORACLE_WHOIS'] = "WHOIS Abfrage f&uuml;r '%1' - '%2'";
+$content['LN_ORACLE_WHOIS'] = "WHOIS Abfrage für '%1' - '%2'";
 
 $content['LN_GEN_ERROR_INVALIDOP'] = "Invalid or missing operation type";
 $content['LN_GEN_ERROR_INVALIDREPORTID'] = "Invalid or missing report id";
@@ -369,5 +368,7 @@ $content['LN_REPORTS_INFORMATION'] = "This page shows a list of installed and av
 <br/>Attention! Generating reports can be very time consuming depending on the size of your database.
 ";
 $content['LN_REPORTS_CHECKLOGSTREAMSOURCE'] = "Verify Logstream optimization";
+$content['LN_REPORTS_RUNNOW'] = "Run saved report now!";
+$content['LN_REPORTS_ERROR_ERRORCHECKINGSOURCE'] = "Error while checking Savedreport Source: %1";
 
 ?>
\ No newline at end of file
