@@ -48,6 +48,7 @@ $content['LN_DELETENO'] = "No";
 $content['LN_GEN_ACTIONS'] = "Available Actions";
 $content['LN_ADMIN_SEND'] = "Send changes";
 $content['LN_GEN_USERONLY'] = "User only";
+$content['LN_GEN_USERONLYNAME'] = "User '%1'";
 $content['LN_GEN_GROUPONLY'] = "Group only";
 $content['LN_GEN_GLOBAL'] = "Global";
 $content['LN_GEN_USERONLY_LONG'] = "For me only <br>(Only available to your user)";
@@ -60,6 +61,9 @@ $content['LN_UPDATE_AVAILABLE'] = "Update available";
 $content['LN_UPDATE_INSTALLEDVER'] = "Installed version: ";
 $content['LN_UPDATE_AVAILABLEVER'] = "Available version: ";
 $content['LN_UPDATE_LINK'] = "Click here to get the update";
+$content['LN_ADMIN_RESULTREDIRECT'] = "You will be redirected to the <A HREF='%1'>this page</A> on %2 seconds.";
+$content['LN_ADMIN_RESULTCLICK'] = "Click <A HREF='%1'>here</A> to continue.";
+$content['LN_ADMIN_GOBACK'] = "Go Back";
 
 // General Options
 $content['LN_ADMIN_GLOBFRONTEND'] = "Global frontend options";
@@ -90,6 +94,8 @@ $content['LN_GEN_CONFIGFILE'] = "Configuration File";
 $content['LN_GEN_ACCESSDENIED'] = "Access denied to this function";
 $content['LN_GEN_DEFVIEWS'] = "Default selected view";
 $content['LN_GEN_DEFSOURCE'] = "Default selected source";
+$content['LN_GEN_DEFFONT'] = "Default Font";
+$content['LN_GEN_DEFFONTSIZE'] = "Default FontSize";
 $content['LN_GEN_SUPPRESSDUPMSG'] = "Suppress duplicated messages";
 $content['LN_GEN_TREATFILTERSTRUE'] = "Treat filters of not found fields as true";
 $content['LN_GEN_INLINESEARCHICONS'] = "Show Onlinesearch icons within fields";
@@ -111,6 +117,7 @@ $content['LN_ADMIN_ERROR_NOTALLOWEDTOEDIT'] = "You are not allowed to edit this
 $content['LN_ADMIN_USEPROXYSERVER'] = "Leave empty if you do not want to use a proxy server! If set to valid proxy server (for example '127.0.0.1:8080'), LogAnalyzer will use this server for remote queries like the update check feature.";
 $content['LN_ADMIN_DEFAULTENCODING'] = "Default character encoding"; 
 $content['LN_GEN_CONTEXTLINKS'] = "Enable Contextlinks (Question marks)";
+$content['LN_GEN_DISABLEADMINUSERS'] = "Disable Adminpanel for normal users";
 
 // User Center
 $content['LN_USER_CENTER'] = "User Options";
@@ -139,7 +146,8 @@ $content['LN_USER_ERROR_INVALIDSESSIONS'] = "Invalid User Session.";
 $content['LN_USER_ERROR_SETTINGFLAG'] = "Error setting flag, invalid ID or User not found";
 $content['LN_USER_WARNRADYONLYADMIN'] = "You are about to set your account to readonly! This will prevent you from changing any settings! Are you sure that you want to proceed?";
 $content['LN_USER_ISREADONLY'] = "Readonly User?";
-$content['LN_USER_'] = "";
+$content['LN_USER_SETISADMIN'] = "Toggle IsAdmin State";
+$content['LN_USER_SETISREADONLY'] = "Toggle IsReadOnly State";
 
 // Group center
 $content['LN_GROUP_CENTER'] = "Group Center";
@@ -226,6 +234,7 @@ $content['LN_DBMP_NAME'] = "Database Mappingname";
 $content['LN_DBMP_DBMAPPINGS'] = "Database Mappings";
 $content['LN_DBMP_ADD'] = "Add new Database Mapping";
 $content['LN_DBMP_EDIT'] = "Edit Database Mapping";
+$content['LN_DBMP_DELETE'] = "Delete Database Mapping";
 $content['LN_DBMP_ERROR_IDNOTFOUND'] = "A Database Mapping with ID '%1' could not be found.";
 $content['LN_DBMP_ERROR_INVALIDID'] = "The Database Mapping with ID '%1' is not a valid Database Mapping.";
 $content['LN_DBMP_WARNDELETEMAPPING'] = "Are you sure that you want to delete the Database Mapping '%1'? This cannot be undone!";
@@ -332,6 +341,7 @@ $content['LN_CHARTS_FILTERSTRING'] = "Custom Filter";
 $content['LN_CHARTS_FILTERSTRING_HELP'] = "Use the same syntax as in the search field. For example if you want to generate a chart for 'server1', use this filter: source:=server1";
 $content['LN_CHARTS_ERROR_CHARTIDNOTFOUND'] = "Error, ChartID with ID '%1' , was not found";
 $content['LN_CHARTS_ERROR_SETTINGFLAG'] = "Error setting flag, invalid ChartID or operation.";
+$content['LN_CHARTS_SETENABLEDSTATE'] = "Toggle Enabled State";
 
 // Fields Options
 $content['LN_FIELDS_CENTER'] = "Fields Options";
@@ -431,11 +441,9 @@ $content['LN_REPORTS_HASBEENEDIT'] = "The Savedreport '%1' has been successfully
 $content['LN_REPORTS_SOURCEID'] = "Logstream source";
 $content['LN_REPORTS_ERROR_SAVEDREPORTIDNOTFOUND'] = "There was no savedreport with ID '%1' found.";
 $content['LN_REPORTS_ERROR_INVALIDSAVEDREPORTID'] = "Invalid savedreport id.";
-$content['LN_REPORTS_RUNNOW'] = "Run saved report now!";
 $content['LN_REPORTS_WARNDELETESAVEDREPORT'] = "Are you sure that you want to delete the savedreport '%1'?";
 $content['LN_REPORTS_ERROR_DELSAVEDREPORT'] = "Deleting of the savedreport with id '%1' failed!";
 $content['LN_REPORTS_ERROR_HASBEENDEL'] = "The savedreport '%1' has been successfully deleted!";
-$content['LN_REPORTS_ERROR_ERRORCHECKINGSOURCE'] = "Error while checking Savedreport Source: %1";
 $content['LN_REPORTS_FILTERLIST'] = "Filterlist";
 $content['LN_REPORTS_FILTER'] = "Filter";
 $content['LN_REPORTS_ADDFILTER'] = "Add filter";
@@ -485,4 +493,4 @@ $content['LN_REPORTS_ERROR_FAILED_SOURCE_CHECK'] = "Failed to check the datasour
 $content['LN_REPORTS_'] = "";
 
 
-?>
\ No newline at end of file
+?>
