@@ -405,6 +405,7 @@ $content['LN_REPORTS_INFORMATION'] = "This page shows a list of installed and av
 <br/>Attention! Generating reports can be very time consuming depending on the size of your database.
 ";
 $content['LN_REPORTS_CHECKLOGSTREAMSOURCE'] = "Verify Logstream optimization";
-
+$content['LN_REPORTS_RUNNOW'] = "Run saved report now!";
+$content['LN_REPORTS_ERROR_ERRORCHECKINGSOURCE'] = "Error while checking Savedreport Source: %1";
 
 ?>
\ No newline at end of file
